@@ -1,8 +1,8 @@
-/* $Id: upnpsoap.c,v 1.155 2019/04/08 13:31:46 nanard Exp $ */
+/* $Id: upnpsoap.c,v 1.157 2020/05/30 08:28:22 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
- * (c) 2006-2019 Thomas Bernard
+ * (c) 2006-2021 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
@@ -27,6 +27,7 @@
 #include "upnpsoap.h"
 #include "upnpreplyparse.h"
 #include "upnpredirect.h"
+#include "upnppermissions.h"
 #include "upnppinhole.h"
 #include "getifaddr.h"
 #include "getifstats.h"
@@ -332,23 +333,27 @@ GetExternalIPAddress(struct upnphttp * h, const char * action, const char * ns)
 	 * There is usually no NAT with IPv6 */
 
 #ifndef MULTIPLE_EXTERNAL_IP
-	struct in_addr addr;
 	if(use_ext_ip_addr)
 	{
 		strncpy(ext_ip_addr, use_ext_ip_addr, INET_ADDRSTRLEN);
 		ext_ip_addr[INET_ADDRSTRLEN - 1] = '\0';
 	}
-	else if(getifaddr(ext_if_name, ext_ip_addr, INET_ADDRSTRLEN, &addr, NULL) < 0)
+	else
 	{
-		syslog(LOG_ERR, "Failed to get ip address for interface %s",
-			ext_if_name);
-		strncpy(ext_ip_addr, "0.0.0.0", INET_ADDRSTRLEN);
+		struct in_addr addr;
+		if(getifaddr(ext_if_name, ext_ip_addr, INET_ADDRSTRLEN, &addr, NULL) < 0)
+		{
+			syslog(LOG_ERR, "Failed to get ip address for interface %s",
+				ext_if_name);
+			ext_ip_addr[0] = '\0';
+		} else if (addr_is_reserved(&addr)) {
+			syslog(LOG_NOTICE, "private/reserved address %s is not suitable for external IP", ext_ip_addr);
+			ext_ip_addr[0] = '\0';
+		}
 	}
-	if (addr_is_reserved(&addr))
-		strncpy(ext_ip_addr, "0.0.0.0", INET_ADDRSTRLEN);
 #else
 	struct lan_addr_s * lan_addr;
-	strncpy(ext_ip_addr, "0.0.0.0", INET_ADDRSTRLEN);
+	ext_ip_addr[0] = '\0';
 	for(lan_addr = lan_addrs.lh_first; lan_addr != NULL; lan_addr = lan_addr->list.le_next)
 	{
 		if( (h->clientaddr.s_addr & lan_addr->mask.s_addr)
@@ -359,11 +364,17 @@ GetExternalIPAddress(struct upnphttp * h, const char * action, const char * ns)
 		}
 	}
 #endif
+	/* WANIPConnection:2 Service 2.3.13 :
+	 * When the external IP address could not be retrieved by the gateway
+	 * (for example, because the interface is down or because there was a
+	 * failure in the last connection setup attempt),
+	 * then the ExternalIPAddress MUST be equal to the empty string.
+	 *
+	 * There is no precise requirement on how theses cases must be handled
+	 * in IGDv1 specifications, but ExternalIPAddress default value is empty
+	 * string. */
 	if (strcmp(ext_ip_addr, "0.0.0.0") == 0)
-	{
-		SoapError(h, 501, "Action Failed");
-		return;
-	}
+		ext_ip_addr[0] = '\0';
 	bodylen = snprintf(body, sizeof(body), resp,
 	              action, ns, /*SERVICE_TYPE_WANIPC,*/
 				  ext_ip_addr, action);
@@ -611,9 +622,12 @@ AddAnyPortMapping(struct upnphttp * h, const char * action, const char * ns)
 		return;
 	}
 
-	eport = (unsigned short)atoi(ext_port);
+	eport = (0 == strcmp(ext_port, "*")) ? 0 : (unsigned short)atoi(ext_port);
+	if (eport == 0) {
+		eport = 1024 + ((random() & 0x7ffffffL) % (65536-1024));
+	}
 	iport = (unsigned short)atoi(int_port);
-	if(iport == 0 || !is_numeric(ext_port)) {
+	if(iport == 0 || (!is_numeric(ext_port) && 0 != strcmp(ext_port, "*"))) {
 		ClearNameValueList(&data);
 		SoapError(h, 402, "Invalid Args");
 		return;
@@ -665,14 +679,42 @@ AddAnyPortMapping(struct upnphttp * h, const char * action, const char * ns)
 		}
 	}
 
-	/* TODO : accept a different external port
-	 * have some smart strategy to choose the port */
-	for(;;) {
-		r = upnp_redirect(r_host, eport, int_ip, iport, protocol, desc, leaseduration);
-		if(r==-2 && eport < 65535) {
-			eport++;
-		} else {
-			break;
+	/* first try the port asked in request, then
+	 * try +1, -1, +2, -2, etc. */
+	r = upnp_redirect(r_host, eport, int_ip, iport, protocol, desc, leaseduration);
+	if (r != 0 && r != -1) {
+		unsigned short eport_below, eport_above;
+		struct in_addr address;
+		uint32_t allowed_eports[65536 / 32];
+
+		if(inet_aton(int_ip, &address) <= 0) {
+			syslog(LOG_ERR, "inet_aton(%s) FAILED", int_ip);
+		}
+		get_permitted_ext_ports(allowed_eports, upnppermlist, num_upnpperm,
+		                        address.s_addr, iport);
+		eport_above = eport_below = eport;
+		for(;;) {
+			/* loop invariant
+			 * eport is equal to either eport_below or eport_above (or both) */
+			if (eport_below <= 1 && eport_above == 65535) {
+				/* all possible ports tried */
+				r = 1;
+				break;
+			}
+			if (eport_above == 65535 || (eport > eport_below && eport_below > 1)) {
+				eport = --eport_below;
+			} else {
+				eport = ++eport_above;
+			}
+			if (!(allowed_eports[eport / 32] & ((uint32_t)1U << (eport % 32))))
+				continue;	/* not allowed */
+			r = upnp_redirect(r_host, eport, int_ip, iport, protocol, desc, leaseduration);
+			if (r == 0 || r == -1) {
+				/* OK or failure : Stop */
+				break;
+			}
+			/* r : -2 / -4 already redirected or -3 permission check failed :
+			 * continue */
 		}
 	}
 
@@ -680,6 +722,9 @@ AddAnyPortMapping(struct upnphttp * h, const char * action, const char * ns)
 
 	switch(r)
 	{
+	case 1:	/* exhausted possible mappings */
+		SoapError(h, 728, "NoPortMapsAvailable");
+		break;
 	case 0:	/* success */
 		bodylen = snprintf(body, sizeof(body), resp,
 		              action, ns, /*SERVICE_TYPE_WANIPC,*/
@@ -771,10 +816,10 @@ GetSpecificPortMappingEntry(struct upnphttp * h, const char * action, const char
 	}
 	else
 	{
-		syslog(LOG_INFO, "%s: rhost='%s' %s %s found => %s:%u desc='%s'",
+		syslog(LOG_INFO, "%s: rhost='%s' %s %s found => %s:%u desc='%s' duration=%u",
 		       action,
 		       r_host ? r_host : "NULL", ext_port, protocol, int_ip,
-		       (unsigned int)iport, desc);
+		       (unsigned int)iport, desc, leaseduration);
 		bodylen = snprintf(body, sizeof(body), resp,
 				action, ns/*SERVICE_TYPE_WANIPC*/,
 				(unsigned int)iport, int_ip, desc, leaseduration,
@@ -1533,23 +1578,35 @@ PinholeVerification(struct upnphttp * h, char * int_ip, unsigned short int_port)
 	if (inet_pton(AF_INET6, int_ip, &result_ip) <= 0)
 	{
 		n = getaddrinfo(int_ip, NULL, &hints, &ai);
-		if(!n && ai->ai_family == AF_INET6)
+		if (n == 0)
 		{
+			int found = 0;
 			for(p = ai; p; p = p->ai_next)
 			{
-				inet_ntop(AF_INET6, (struct in6_addr *) p, int_ip, sizeof(struct in6_addr));
-				result_ip = *((struct in6_addr *) p);
-				/* TODO : deal with more than one ip per hostname */
-				break;
+				if(p->ai_family == AF_INET6)
+				{
+					inet_ntop(AF_INET6, (struct in6_addr *) p, int_ip, sizeof(struct in6_addr));
+					result_ip = *((struct in6_addr *) p);
+					found = 1;
+					/* TODO : deal with more than one ip per hostname */
+					break;
+				}
+			}
+			freeaddrinfo(ai);
+			if (!found)
+			{
+				syslog(LOG_NOTICE, "No IPv6 address for hostname '%s'", int_ip);
+				SoapError(h, 402, "Invalid Args");
+				return -1;
 			}
 		}
 		else
 		{
-			syslog(LOG_ERR, "Failed to convert hostname '%s' to ip address", int_ip);
+			syslog(LOG_WARNING, "Failed to convert hostname '%s' to IP address : %s",
+			       int_ip, gai_strerror(n));
 			SoapError(h, 402, "Invalid Args");
 			return -1;
 		}
-        freeaddrinfo(p);
 	}
 
 	if(inet_ntop(AF_INET6, &(h->clientaddr_v6), senderAddr, INET6_ADDRSTRLEN) == NULL)
