@@ -3,10 +3,9 @@ include("script/campaign/libcampaign.js");
 include("script/campaign/templates.js");
 
 const TRANSPORT_LIMIT = 4;
-var index; //Number of transport loads sent into the level
+var transporterIndex; //Number of transport loads sent into the level
 var startedFromMenu;
 
-
 camAreaEvent("vtolRemoveZone", function(droid)
 {
 	camSafeRemoveObject(droid, false);
@@ -60,7 +59,7 @@ function getDroidsForCOLZ()
 		usingHeavy = true;
 	}
 
-	for (var i = 0; i < count; ++i)
+	for (let i = 0; i < count; ++i)
 	{
 		if (!i && usingHeavy)
 		{
@@ -101,12 +100,12 @@ function sendCOTransporter()
 //from the main menu. Otherwise a player can just bring in there Alpha units
 function sendPlayerTransporter()
 {
-	if (!camDef(index))
+	if (!camDef(transporterIndex))
 	{
-		index = 0;
+		transporterIndex = 0;
 	}
 
-	if (index === TRANSPORT_LIMIT)
+	if (transporterIndex === TRANSPORT_LIMIT)
 	{
 		downTransporter();
 		return;
@@ -115,7 +114,7 @@ function sendPlayerTransporter()
 	var droids = [];
 	var list = [cTempl.prhct, cTempl.prhct, cTempl.prhct, cTempl.prltat, cTempl.prltat, cTempl.npcybr, cTempl.prrept];
 
-	for (var i = 0; i < 10; ++i)
+	for (let i = 0; i < 10; ++i)
 	{
 		droids.push(list[camRand(list.length)]);
 	}
@@ -135,7 +134,7 @@ function mapEdgeDroids()
 	var list = [cTempl.npcybm, cTempl.npcybr, cTempl.commrp, cTempl.cohct];
 
 	var droids = [];
-	for (var i = 0; i < TankNum; ++i)
+	for (let i = 0; i < TankNum; ++i)
 	{
 		droids.push(list[camRand(list.length)]);
 	}
@@ -200,7 +199,7 @@ function cam2Setup()
 		"R-Wpn-RocketSlow-Damage04", "R-Sys-Sensor-Upgrade01"
 	];
 
-	for (var x = 0, l = STRUCTS_ALPHA.length; x < l; ++x)
+	for (let x = 0, l = STRUCTS_ALPHA.length; x < l; ++x)
 	{
 		enableStructure(STRUCTS_ALPHA[x], CAM_HUMAN_PLAYER);
 	}
@@ -210,26 +209,40 @@ function cam2Setup()
 	camCompleteRequiredResearch(COLLECTIVE_RES, THE_COLLECTIVE);
 	camCompleteRequiredResearch(ALPHA_RESEARCH_NEW, CAM_HUMAN_PLAYER);
 
+	if (difficulty >= HARD)
+	{
+		camUpgradeOnMapTemplates(cTempl.commc, cTempl.commrp, THE_COLLECTIVE);
+	}
+
 	enableResearch("R-Wpn-Cannon-Damage04", CAM_HUMAN_PLAYER);
 	enableResearch("R-Wpn-Rocket-Damage04", CAM_HUMAN_PLAYER);
 	preDamageStuff();
 }
 
-//Get some higher rank droids at start and first Transport drop.
-function setUnitRank()
+//Get some higher rank droids.
+function setUnitRank(transport)
 {
-	const DROID_EXP = 32;
-	const MIN_TO_AWARD = 16;
-	var droids = enumDroid(CAM_HUMAN_PLAYER).filter(function(dr) {
-		return (!camIsSystemDroid(dr) && !camIsTransporter(dr));
-	});
+	const DROID_EXP = [128, 64, 32, 16];
+	var droids;
+	var mapRun = false;
 
-	for (var j = 0, i = droids.length; j < i; ++j)
+	if (transport)
 	{
-		var droid = droids[j];
-		if (Math.floor(droid.experience) < MIN_TO_AWARD)
+		droids = enumCargo(transport);
+	}
+	else
+	{
+		mapRun = true;
+		//These are the units in the base already at the start.
+		droids = enumDroid(CAM_HUMAN_PLAYER).filter((dr) => (!camIsTransporter(dr)));
+	}
+
+	for (let i = 0, len = droids.length; i < len; ++i)
+	{
+		var droid = droids[i];
+		if (!camIsSystemDroid(droid))
 		{
-			setDroidExperience(droids[j], DROID_EXP);
+			setDroidExperience(droid, DROID_EXP[mapRun ? 0 : (transporterIndex - 1)]);
 		}
 	}
 }
@@ -239,18 +252,19 @@ function eventTransporterLanded(transport)
 {
 	if (transport.player === CAM_HUMAN_PLAYER)
 	{
+		if (!camDef(transporterIndex))
+		{
+			transporterIndex = 0;
+		}
+
+		transporterIndex += 1;
+
 		if (startedFromMenu)
 		{
-			camCallOnce("setUnitRank");
+			setUnitRank(transport);
 		}
 
-		if (!camDef(index))
-		{
-			index = 0;
-		}
-
-		index = index + 1;
-		if (index >= TRANSPORT_LIMIT)
+		if (transporterIndex >= TRANSPORT_LIMIT)
 		{
 			queue("downTransporter", camMinutesToMilliseconds(1));
 		}
@@ -275,7 +289,7 @@ function downTransporter()
 
 function eventTransporterLaunch(transport)
 {
-	if (index >= TRANSPORT_LIMIT)
+	if (transporterIndex >= TRANSPORT_LIMIT)
 	{
 		queue("downTransporter", camMinutesToMilliseconds(1));
 	}
@@ -283,7 +297,7 @@ function eventTransporterLaunch(transport)
 
 function eventGameLoaded()
 {
-	if (index >= TRANSPORT_LIMIT)
+	if (transporterIndex >= TRANSPORT_LIMIT)
 	{
 		setReinforcementTime(LZ_COMPROMISED_TIME);
 	}
@@ -303,7 +317,7 @@ function eventStartLevel()
 
 	centreView(startpos.x, startpos.y);
 	setNoGoArea(lz.x, lz.y, lz.x2, lz.y2, CAM_HUMAN_PLAYER);
-	setNoGoArea(enemyLz.x, enemyLz.y, enemyLz.x2, enemyLz.y2, THE_COLLECTIVE);
+	setNoGoArea(enemyLz.x, enemyLz.y, enemyLz.x2, enemyLz.y2, 5);
 	startTransporterEntry(tent.x, tent.y, CAM_HUMAN_PLAYER);
 	setTransporterExit(text.x, text.y, CAM_HUMAN_PLAYER);
 
@@ -334,7 +348,6 @@ function eventStartLevel()
 	});
 
 	camManageTrucks(THE_COLLECTIVE);
-	truckDefense();
 	setUnitRank(); //All pre-placed player droids are ranked.
 	camPlayVideos({video: "MB2A_MSG", type: MISS_MSG});
 	startedFromMenu = false;
@@ -357,4 +370,6 @@ function eventStartLevel()
 	setTimer("truckDefense", camChangeOnDiff(camMinutesToMilliseconds(3)));
 	setTimer("sendCOTransporter", camChangeOnDiff(camMinutesToMilliseconds(4)));
 	setTimer("mapEdgeDroids", camChangeOnDiff(camMinutesToMilliseconds(7)));
+
+	truckDefense();
 }
