@@ -57,7 +57,7 @@ function sendEdgeMapDroids()
 		edgeMapCounter = 0;
 	}
 
-	for (var i = 0; i < unitCount; ++i)
+	for (let i = 0; i < unitCount; ++i)
 	{
 		droids.push(list[camRand(list.length)]);
 	}
@@ -94,7 +94,7 @@ function truckDefense()
 		"NX-Tower-ATMiss", "Sys-NX-CBTower",
 	];
 
-	for (var i = 0, len = droids.length; i < len; ++i)
+	for (let i = 0, len = droids.length; i < len; ++i)
 	{
 		var truck = droids[i];
 		if (truck.order !== DORDER_BUILD)
@@ -130,12 +130,12 @@ function nexusManufacture()
 		{structure: VTOL_FACTORY, temps: [cTempl.nxlscouv, cTempl.nxmtherv, cTempl.nxmheapv,]},
 	];
 
-	for (var i = 0; i < factoryType.length; ++i)
+	for (let i = 0; i < factoryType.length; ++i)
 	{
 		var factories = enumStruct(NEXUS, factoryType[i].structure);
 		var templs = factoryType[i].temps;
 
-		for (var j = 0, len = factories.length; j < len; ++j)
+		for (let j = 0, len = factories.length; j < len; ++j)
 		{
 			var fac = factories[j];
 			if (fac.status !== BUILT || !structureIdle(fac))
@@ -151,12 +151,8 @@ function nexusManufacture()
 
 function manualGrouping()
 {
-	var vtols = enumDroid(NEXUS).filter(function(obj) {
-		return obj.group === null && isVTOL(obj);
-	});
-	var nonVtols = enumDroid(NEXUS).filter(function(obj) {
-		return obj.group === null && !isVTOL(obj);
-	});
+	var vtols = enumDroid(NEXUS).filter((obj) => (obj.group === null && isVTOL(obj)));
+	var nonVtols = enumDroid(NEXUS).filter((obj) => (obj.group === null && !isVTOL(obj)));
 	if (vtols.length)
 	{
 		camManageGroup(camMakeGroup(vtols), CAM_ORDER_ATTACK, { regroup: false, count: -1 });
@@ -195,11 +191,11 @@ function eventResearched(research, structure, player)
 	}
 	else if (research.name === "R-Sys-Resistance-Upgrade02")
 	{
-		hackFailChance = 80;
+		hackFailChance = 70;
 	}
 	else if (research.name === "R-Sys-Resistance-Upgrade03")
 	{
-		hackFailChance = 95;
+		hackFailChance = 85;
 	}
 	else if (research.name === "R-Sys-Resistance-Upgrade04")
 	{
@@ -233,8 +229,8 @@ function synapticsSound()
 //winFlag is set in eventResearched.
 function resistanceResearched()
 {
-	const MIN_EDGE_COUNT = 15;
-	if (winFlag && edgeMapCounter >= MIN_EDGE_COUNT)
+	let mapEdgeCount = (difficulty >= MEDIUM) ? 15 : 8;
+	if (winFlag && edgeMapCounter >= mapEdgeCount)
 	{
 		return true;
 	}
@@ -265,16 +261,16 @@ function eventStartLevel()
 
 	enableResearch("R-Sys-Resistance-Upgrade01", CAM_HUMAN_PLAYER);
 	winFlag = false;
-	hackFailChance = 30;
+	hackFailChance = (difficulty <= EASY) ? 40 : 30;
 
-	vtolAttack();
+	queue("vtolAttack", camChangeOnDiff(camMinutesToMilliseconds(2)));
 
 	queue("powerTransfer", camSecondsToMilliseconds(0.8));
 	queue("synapticsSound", camSecondsToMilliseconds(2.5));
 	queue("sendEdgeMapDroids", camSecondsToMilliseconds(15));
 
 	setTimer("truckDefense", camSecondsToMilliseconds(2));
-	setTimer("hackPlayer", camSecondsToMilliseconds((difficulty <= HARD) ? 8 : 5));
+	setTimer("hackPlayer", camChangeOnDiff(camSecondsToMilliseconds(8)));
 	setTimer("nexusManufacture", camSecondsToMilliseconds(10));
 	setTimer("sendEdgeMapDroids", camChangeOnDiff(camMinutesToMilliseconds(3)));
 }
