@@ -105,9 +105,9 @@ function phantomFactorySpawn()
 function vaporizeTarget()
 {
 	var target;
-	var targets = enumArea(0, Y_SCROLL_LIMIT, mapWidth, Math.floor(mapLimit), CAM_HUMAN_PLAYER, false).filter(function(obj) {
-		return obj.type === DROID || obj.type === STRUCTURE;
-	});
+	var targets = enumArea(0, Y_SCROLL_LIMIT, mapWidth, Math.floor(mapLimit), CAM_HUMAN_PLAYER, false).filter((obj) => (
+		obj.type === DROID || obj.type === STRUCTURE
+	));
 
 	if (!targets.length)
 	{
@@ -124,9 +124,9 @@ function vaporizeTarget()
 	}
 	else
 	{
-		var dr = targets.filter(function(obj) { return obj.type === DROID && !isVTOL(obj); });
-		var vt = targets.filter(function(obj) { return obj.type === DROID && isVTOL(obj); });
-		var st = targets.filter(function(obj) { return obj.type === STRUCTURE; });
+		var dr = targets.filter((obj) => (obj.type === DROID && !isVTOL(obj)));
+		var vt = targets.filter((obj) => (obj.type === DROID && isVTOL(obj)));
+		var st = targets.filter((obj) => (obj.type === STRUCTURE));
 
 		if (dr.length)
 		{
@@ -142,7 +142,6 @@ function vaporizeTarget()
 		}
 	}
 
-
 	//Stop firing LasSat if the third missile unlock code was researched.
 	if (winFlag === false)
 	{
@@ -158,7 +157,7 @@ function vaporizeTarget()
 			//119 tiles / 60 minutes = 1.983 tiles per minute
 			//1.983 tile per minute / 60 seconds = 0.03305 tiles per second
 			//0.03305 * 10 sec = ~0.33 tiles per blast at 10 second intervals.
-			mapLimit = mapLimit + 0.33; //sector clear; move closer
+			mapLimit += 0.33; //sector clear; move closer
 		}
 		laserSatFuzzyStrike(target);
 	}
@@ -226,7 +225,7 @@ function laserSatFuzzyStrike(obj)
 //Play videos and allow winning once the final one is researched.
 function eventResearched(research, structure, player)
 {
-	for (var i = 0, l = videoInfo.length; i < l; ++i)
+	for (let i = 0, l = videoInfo.length; i < l; ++i)
 	{
 		if (research.name === videoInfo[i].res && !videoInfo[i].played)
 		{
@@ -298,7 +297,7 @@ function eventStartLevel()
 
 	//Destroy everything above limits
 	var destroyZone = enumArea(0, 0, 64, Y_SCROLL_LIMIT, CAM_HUMAN_PLAYER, false);
-	for (var i = 0, l = destroyZone.length; i < l; ++i)
+	for (let i = 0, l = destroyZone.length; i < l; ++i)
 	{
 		camSafeRemoveObject(destroyZone[i], false);
 	}
@@ -308,9 +307,6 @@ function eventStartLevel()
 	setMissionTime(camMinutesToSeconds(5));
 	enableResearch("R-Sys-Resistance", CAM_HUMAN_PLAYER);
 
-	var enemyLz = getObject("NXlandingZone");
-	setNoGoArea(enemyLz.x, enemyLz.y, enemyLz.x2, enemyLz.y2, NEXUS);
-
 	camCompleteRequiredResearch(NEXUS_RES, NEXUS);
 	camPlayVideos({video: "MB3_AD2_MSG", type: MISS_MSG});
 
