@@ -10,75 +10,71 @@
 
 //;; ## camSetFactories(factories)
 //;;
-//;; Tell ```libcampaign.js``` to manage a certain set of enemy factories.
+//;; Tell `libcampaign.js` to manage a certain set of enemy factories.
 //;; Management assumes producing droids, packing them into groups and
 //;; executing orders once the group becomes large-enough.
 //;; The argument is a JavaScript map from group labels to factory descriptions.
-//;; Each label points to a factory object. Factory description
+//;; Each label points to a factory object.
+//;; Factory description is a JavaScript object with the following fields:
+//;; * `assembly` A rally point position label, where the group would gather.
+//;; * `order` An order to execute for every group produced in the factory. Same as the order parameter for `camManageGroup()`.
+//;; * `data` Order data. Same as the data parameter for `camManageGroup()`.
+//;; * `groupSize` Number of droids to produce before executing the order.
+//;;   Also, if order is `CAM_ORDER_ATTACK`, data.count defaults to this value.
+//;; * `maxSize` Halt production when reaching that many droids in the factory group.
+//;;   Resume when some droids die. Unlimited if unspecified.
+//;; * `throttle` If defined, produce droids only every that many milliseconds, and keep the factory idle between ticks.
+//;; * `group` If defined, make the factory manage this group, otherwise create a new empty group to manage.
+//;;   Droids produced in the factory would automatically be added to the group,
+//;;   and order and data parameters would be applied to this group.
+//;; * `templates` List of droid templates to produce in the factory.
+//;;   Each template is a JavaScript object with the following fields:
+//;;   * `body` Body stat name.
+//;;   * `prop` Propulsion stat name.
+//;;   * `weap` Weapon stat name. Only single-turret droids are currently supported.
+//;;   Note that all template components are automatically made available to the factory owner.
+//;; Factories won't start production immediately; call `camEnableFactory()` to turn them on when necessary.
 //;;
-//;; is a JavaScript object with the following fields:
-//;; * ```assembly``` A rally point position label, where the group would
-//;; 	gather.
-//;; * ```order``` An order to execute for every group produced in the
-//;; 	factory. Same as the order parameter for ```camManageGroup()```.
-//;; * ```data``` Order data. Same as the data parameter for
-//;; 	```camManageGroup()```.
-//;; * ```groupSize``` Number of droids to produce before executing the order.
-//;; 	Also, if order is ```CAM_ORDER_ATTACK```, data.count defaults to this value.
-//;; * ```maxSize``` Halt production when reaching that many droids in the
-//;; 	factory group. Resume when some droids die. Unlimited if unspecified.
-//;; * ```throttle``` If defined, produce droids only every that many
-//;; 	milliseconds, and keep the factory idle between ticks.
-//;; * ```group``` If defined, make the factory manage this group,
-//;; 	otherwise create a new empty group to manage.
-//;; 	Droids produced in the factory would automatically be
-//;; 	added to the group, and order and data parameters
-//;; 	would be applied to this group.
-//;; * ```templates``` List of droid templates to produce in the factory.
-//;; 	Each template is a JavaScript object with the following fields:
-//;;   * ```body``` Body stat name.
-//;;   * ```prop``` Propulsion stat name.
-//;;   * ```weap``` Weapon stat name. Only single-turret droids are
-//;; 		currently supported.
-//;; 	Note that all template components are automatically made available
-//;; 	to the factory owner.
-//;; Factories won't start production immediately; call
-//;; ```camEnableFactory()``` to turn them on when necessary.
+//;; @param {Object} factories
+//;; @returns {void}
 //;;
 function camSetFactories(factories)
 {
-	for (var flabel in factories)
+	for (const factoryLabel in factories)
 	{
-		camSetFactoryData(flabel, factories[flabel]);
+		camSetFactoryData(factoryLabel, factories[factoryLabel]);
 	}
 }
 
-//;; ## camSetFactoryData(factory label, factory description)
+//;; ## camSetFactoryData(factoryLabel, factoryData)
 //;;
-//;; Similar to ```camSetFactories()```, but one factory at a time.
-//;; If the factory was already managing a group of droids, it keeps
-//;; managing it. If a new group is specified in the description,
-//;; the old group is merged into it. NOTE: This function disables the
-//;; factory. You would need to call ```camEnableFactory()``` again.
+//;; Similar to `camSetFactories()`, but one factory at a time.
+//;; If the factory was already managing a group of droids, it keeps managing it.
+//;; If a new group is specified in the description, the old group is merged into it.
+//;; NOTE: This function disables the factory. You would need to call `camEnableFactory()` again.
 //;;
-function camSetFactoryData(flabel, fdata)
+//;; @param {string} factoryLabel
+//;; @param {Object} factoryData
+//;; @returns {void}
+//;;
+function camSetFactoryData(factoryLabel, factoryData)
 {
-	var structure = getObject(flabel);
+	var structure = getObject(factoryLabel);
 	if (!camDef(structure) || !structure)
 	{
 		// Not an error! It's ok if the factory is already destroyed
 		// when its data was updated.
-		camTrace("Factory", flabel, "not found");
+		camTrace("Factory", factoryLabel, "not found");
 		return;
 	}
 	// remember the old factory group, if any
 	var droids = [];
-	if (camDef(__camFactoryInfo[flabel]))
+	if (camDef(__camFactoryInfo[factoryLabel]))
 	{
-		droids = enumGroup(__camFactoryInfo[flabel].group);
+		droids = enumGroup(__camFactoryInfo[factoryLabel].group);
 	}
-	__camFactoryInfo[flabel] = fdata;
-	var fi = __camFactoryInfo[flabel];
+	__camFactoryInfo[factoryLabel] = factoryData;
+	var fi = __camFactoryInfo[factoryLabel];
 	if (!camDef(fi.data))
 	{
 		fi.data = {};
@@ -89,7 +85,7 @@ function camSetFactoryData(flabel, fdata)
 	{
 		fi.group = camNewGroup();
 	}
-	for (var i = 0, l = droids.length; i < l; ++i)
+	for (let i = 0, l = droids.length; i < l; ++i)
 	{
 		var droid = droids[i];
 		groupAdd(fi.group, droid);
@@ -100,94 +96,108 @@ function camSetFactoryData(flabel, fdata)
 	}
 }
 
-//;; ## camEnableFactory(factory label)
+//;; ## camEnableFactory(factoryLabel)
 //;;
-//;; Enable a managed factory by the given label. Once the factory is enabled,
-//;; it starts producing units and executing orders as given.
+//;; Enable a managed factory by the given label.
+//;; Once the factory is enabled, it starts producing units and executing orders as given.
 //;;
-function camEnableFactory(flabel)
+//;; @param {string} factoryLabel
+//;; @returns {void}
+//;;
+function camEnableFactory(factoryLabel)
 {
-	var fi = __camFactoryInfo[flabel];
+	var fi = __camFactoryInfo[factoryLabel];
 	if (!camDef(fi) || !fi)
 	{
-		camDebug("Factory not managed", flabel);
+		camDebug("Factory not managed", factoryLabel);
 		return;
 	}
 	if (fi.enabled)
 	{
 		// safe, no error
-		camTrace("Factory", flabel, "enabled again");
+		camTrace("Factory", factoryLabel, "enabled again");
 		return;
 	}
-	camTrace("Enabling", flabel);
+	camTrace("Enabling", factoryLabel);
 	fi.enabled = true;
-	var obj = getObject(flabel);
+	var obj = getObject(factoryLabel);
 	if (!camDef(obj) || !obj)
 	{
-		camTrace("Factory", flabel, "not found, probably already dead");
+		camTrace("Factory", factoryLabel, "not found, probably already dead");
 		return;
 	}
-	__camContinueProduction(flabel);
-	__camFactoryUpdateTactics(flabel);
+	__camContinueProduction(factoryLabel);
+	__camFactoryUpdateTactics(factoryLabel);
 }
 
-//;; ## camQueueDroidProduction(player, template)
+//;; ## camQueueDroidProduction(playerId, template)
 //;;
-//;; Queues up an extra droid template for production. It would be produced
-//;; in the first factory that is capable of producing it, at the end of
-//;; its production loop, first queued first served.
+//;; Queues up an extra droid template for production.
+//;; It would be produced in the first factory that is capable of producing it,
+//;; at the end of its production loop, first queued first served.
 //;;
-function camQueueDroidProduction(player, template)
+//;; @param {number} playerId
+//;; @param {Object} template
+//;; @returns {void}
+//;;
+function camQueueDroidProduction(playerId, template)
 {
-	if (!camDef(__camFactoryQueue[player]))
+	if (!camDef(__camFactoryQueue[playerId]))
 	{
-		__camFactoryQueue[player] = [];
+		__camFactoryQueue[playerId] = [];
 	}
-	__camFactoryQueue[player][__camFactoryQueue[player].length] = template;
+	__camFactoryQueue[playerId][__camFactoryQueue[playerId].length] = template;
 }
 
-//;; ## camSetPropulsionTypeLimit(number)
+//;; ## camSetPropulsionTypeLimit([limit])
 //;;
-//;; On hard and insane the propulsion type can be limited with this. For type II
-//;; pass in 2, and for type III pass in 3. Hard defaults to type II and
-//;; insane defaults to type III. If nothing is passed in then the type
-//;; limit will match what is in templates.json.
+//;; On hard and insane the propulsion type can be limited with this.
+//;; For type II pass in `2`, and for type III pass in `3`. Hard defaults to type II and insane defaults to type III.
+//;; If nothing is passed in then the type limit will match what is in templates.json.
 //;;
-function camSetPropulsionTypeLimit(num)
+//;; @param {number} [limit]
+//;; @returns {void}
+//;;
+function camSetPropulsionTypeLimit(limit)
 {
-	if (!camDef(num))
+	if (!camDef(limit))
 	{
 		__camPropulsionTypeLimit = "NO_USE";
 	}
-	else if (num === 2)
+	else if (limit === 2)
 	{
 		__camPropulsionTypeLimit = "02";
 	}
-	else if (num === 3)
+	else if (limit === 3)
 	{
 		__camPropulsionTypeLimit = "03";
 	}
 }
 
-//;; ## camUpgradeOnMapTemplates(template1, template2, player, [excluded object IDs])
+//;; ## camUpgradeOnMapTemplates(template1, template2, playerId[, excluded])
 //;;
-//;; Search for template1, save its coordinates, remove it, and then replace with it
-//;; with template2. Template objects are expected to follow the component properties
-//;; as used in templates.js. A fourth parameter can be specified to ignore specific object
-//;; IDs. Useful if a droid is assigned to an object label. It can be either an array
-//;; or a single ID number.
+//;; Search for `template1`, save its coordinates, remove it, and then replace with it with `template2`.
+//;; Template objects are expected to follow the component properties as used in `templates.js`.
+//;; A fourth parameter can be specified to ignore specific object IDs.
+//;; Useful if a droid is assigned to an object label. It can be either an array or a single ID number.
 //;;
-function camUpgradeOnMapTemplates(t1, t2, player, excluded)
+//;; @param {Object} template1
+//;; @param {Object} template2
+//;; @param {number} playerId
+//;; @param {number|number[]} [excluded]
+//;; @returns {void}
+//;;
+function camUpgradeOnMapTemplates(template1, template2, playerId, excluded)
 {
-	if (!camDef(t1) || !camDef(t2) || !camDef(player))
+	if (!camDef(template1) || !camDef(template2) || !camDef(playerId))
 	{
 		camDebug("Not enough parameters specified for upgrading on map templates");
 		return;
 	}
 
-	var droidsOnMap = enumDroid(player);
+	var droidsOnMap = enumDroid(playerId);
 
-	for (var i = 0, l = droidsOnMap.length; i < l; ++i)
+	for (let i = 0, l = droidsOnMap.length; i < l; ++i)
 	{
 		var dr = droidsOnMap[i];
 		if (!camDef(dr.weapons[0]))
@@ -198,14 +208,14 @@ function camUpgradeOnMapTemplates(t1, t2, player, excluded)
 		var prop = dr.propulsion;
 		var weap = dr.weapons[0].name;
 		var skip = false;
-		if (body === t1.body && prop === t1.prop && weap === t1.weap)
+		if (body === template1.body && prop === template1.prop && weap === template1.weap)
 		{
 			//Check if this object should be excluded from the upgrades
 			if (camDef(excluded))
 			{
 				if (excluded instanceof Array)
 				{
-					for (var j = 0, c = excluded.length; j < c; ++j)
+					for (let j = 0, c = excluded.length; j < c; ++j)
 					{
 						if (dr.id === excluded[j])
 						{
@@ -227,8 +237,8 @@ function camUpgradeOnMapTemplates(t1, t2, player, excluded)
 			//Replace it
 			let droidInfo = {x: dr.x, y: dr.y, name: dr.name};
 			camSafeRemoveObject(dr, false);
-			addDroid(player, droidInfo.x, droidInfo.y, droidInfo.name, t2.body,
-				__camChangePropulsionOnDiff(t2.prop), "", "", t2.weap);
+			addDroid(playerId, droidInfo.x, droidInfo.y, droidInfo.name, template2.body,
+				__camChangePropulsionOnDiff(template2.prop), "", "", template2.weap);
 		}
 	}
 }
@@ -288,7 +298,7 @@ function __camAddDroidToFactoryGroup(droid, structure)
 
 function __camChangePropulsionOnDiff(propulsion)
 {
-	if (difficulty === EASY || difficulty === MEDIUM)
+	if (difficulty <= MEDIUM)
 	{
 		return propulsion;
 	}
@@ -309,7 +319,7 @@ function __camChangePropulsionOnDiff(propulsion)
 		name = name.substring(0, name.length - 2);
 	}
 
-	for (var i = 0, l = VALID_PROPS.length; i < l; ++i)
+	for (let i = 0, l = VALID_PROPS.length; i < l; ++i)
 	{
 		var currentProp = VALID_PROPS[i];
 		if (name === currentProp)
@@ -360,7 +370,7 @@ function __camBuildDroid(template, structure)
 //cam_eventDroidBuilt (or the mere act of reloading saves).
 function __checkEnemyFactoryProductionTick()
 {
-	for (var flabel in __camFactoryInfo)
+	for (const flabel in __camFactoryInfo)
 	{
 		if (getObject(flabel) !== null && __camFactoryInfo[flabel].enabled === true)
 		{
