@@ -3,41 +3,45 @@
 // Truck management.
 ////////////////////////////////////////////////////////////////////////////////
 
-//;; ## camManageTrucks(player)
+//;; ## camManageTrucks(playerId)
 //;;
-//;; Manage trucks for an AI player. This assumes recapturing oils and
-//;; rebuilding destroyed trucks in factories, the latter is implemented
-//;; via ```camQueueDroidProduction()``` mechanism.
+//;; Manage trucks for an AI player. This assumes recapturing oils and rebuilding destroyed trucks
+//;; in factories, the latter is implemented via `camQueueDroidProduction()` mechanism.
 //;;
-function camManageTrucks(player)
+//;; @param {number} playerId
+//;; @returns {void}
+//;;
+function camManageTrucks(playerId)
 {
-	__camTruckInfo[player] = { enabled: 1, queue: [], player: player };
+	__camTruckInfo[playerId] = { enabled: 1, queue: [], player: playerId };
 }
 
-//;; ## camQueueBuilding(player, stat[, pos])
+//;; ## camQueueBuilding(playerId, stat[, position])
 //;;
-//;; Assuming truck management is enabled for the player, issue an order
-//;; to build a specific building near a certain position. The order
-//;; would be issued once as soon as a free truck becomes available. It will
-//;; not be re-issued in case the truck is destroyed before the building
-//;; is finished. If position is unspecified, the building would be built
-//;; near the first available truck. Otherwise, position may be a label
-//;; or a POSITION-like object.
+//;; Assuming truck management is enabled for the player, issue an order to build a specific building
+//;; near a certain position. The order would be issued once as soon as a free truck becomes available.
+//;; It will not be re-issued in case the truck is destroyed before the building is finished.
+//;; If position is unspecified, the building would be built near the first available truck.
+//;; Otherwise, position may be a label or a `POSITION`-like object.
 //;;
-function camQueueBuilding(player, stat, pos)
+//;; @param {number} playerId
+//;; @param {string} stat
+//;; @param {string|Object} [position]
+//;; @returns {void}
+//;;
+function camQueueBuilding(playerId, stat, position)
 {
-	var ti = __camTruckInfo[player];
-	ti.queue.push({ stat: stat, pos: camMakePos(pos) });
+	var ti = __camTruckInfo[playerId];
+	ti.queue.push({ stat: stat, pos: camMakePos(position) });
 }
 
-
 //////////// privates
 
 function __camEnumFreeTrucks(player)
 {
 	var rawDroids = enumDroid(player, DROID_CONSTRUCT);
 	var droids = [];
-	for (var i = 0, l = rawDroids.length; i < l; ++i)
+	for (let i = 0, l = rawDroids.length; i < l; ++i)
 	{
 		var droid = rawDroids[i];
 		if (droid.order !== DORDER_BUILD && droid.order !== DORDER_HELPBUILD && droid.order !== DORDER_LINEBUILD)
@@ -59,7 +63,7 @@ function __camGetClosestTruck(player, pos)
 	// Find out which one is the closest.
 	var minDroid = droids[0];
 	var minDist = camDist(minDroid, pos);
-	for (var i = 1, l = droids.length; i < l; ++i)
+	for (let i = 1, l = droids.length; i < l; ++i)
 	{
 		var droid = droids[i];
 		if (!droidCanReach(droid, pos.x, pos.y))
@@ -80,7 +84,7 @@ function __camTruckTick()
 {
 	// Issue truck orders for each player.
 	// See comments inside the loop to understand priority.
-	for (var playerObj in __camTruckInfo)
+	for (const playerObj in __camTruckInfo)
 	{
 		var ti = __camTruckInfo[playerObj];
 		var player = ti.player;
