@@ -6,40 +6,43 @@
 // Be aware that eventVideoDone will be triggered for each video
 // and will be received by the mission script's eventVideoDone, should it exist.
 
-//;; ## camPlayVideos(obj)
+//;; ## camPlayVideos(data)
 //;;
-//;; Formats for parameter obj: {video: "video string", type: MISS_MSG/CAMP_MSG, immediate: true/false} OR
-//;; ["sound file", {video: "video string", type: MISS_MSG/CAMP_MSG, immediate: true/false}, ...]
+//;; Formats for parameter `data`: `{video: "video string", type: MISS_MSG/CAMP_MSG, immediate: true/false}` OR
+//;; `["sound file", {video: "video string", type: MISS_MSG/CAMP_MSG, immediate: true/false}, ...]`
 //;; object property "immediate" is optional since most videos are immediate.
-//;; If videos is an array, queue up all of them for immediate playing. This
-//;; function will play one video sequence should one be provided. Also,
-//;; should a sound file be in a string (pcvX.ogg)  __camEnqueueVideos() will recognize it
-//;; as a sound to play before a video. Of which is only supported when parameter obj is an array.
+//;; If videos is an array, queue up all of them for immediate playing.
+//;; This function will play one video sequence should one be provided.
+//;; Also, should a sound file be in a string (`pcvX.ogg`) `__camEnqueueVideos()` will recognize it
+//;; as a sound to play before a video. Of which is only supported when parameter `data` is an array.
 //;;
-function camPlayVideos(obj)
+//;; @param {Object|Object[]} data
+//;; @returns {void}
+//;;
+function camPlayVideos(data)
 {
-	if (obj instanceof Array)
+	if (data instanceof Array)
 	{
-		__camVideoSequences = obj;
+		__camVideoSequences = data;
 		__camEnqueueVideos();
 	}
-	else if (obj instanceof Object)
+	else if (data instanceof Object)
 	{
-		if (!camDef(obj.video) || !camIsString(obj.video))
+		if (!camDef(data.video) || !camIsString(data.video))
 		{
 			camDebug("Problem with video property.");
 			return;
 		}
-		if (!camDef(obj.type) || (obj.type !== MISS_MSG && obj.type !== CAMP_MSG))
+		if (!camDef(data.type) || (data.type !== MISS_MSG && data.type !== CAMP_MSG))
 		{
 			camDebug("Video message type was NOT specified. Please specify one.");
 			return;
 		}
-		if (!camDef(obj.immediate))
+		if (!camDef(data.immediate))
 		{
-			obj.immediate = true;
+			data.immediate = true;
 		}
-		hackAddMessage(obj.video, obj.type, CAM_HUMAN_PLAYER, obj.immediate);
+		hackAddMessage(data.video, data.type, CAM_HUMAN_PLAYER, data.immediate);
 	}
 	else
 	{
