@@ -70,6 +70,7 @@ nphbb: { body: "Body12SUP", prop: "hover01", weap: "Rocket-BB" },
 commgt: { body: "Body6SUPP", prop: "tracked01", weap: "MG3Mk1" },
 comsens: { body: "Body6SUPP", prop: "tracked01", weap: "SensorTurret1Mk1" },
 cohct: { body: "Body9REC", prop: "tracked01", weap: "Cannon375mmMk1" },
+commc: { body: "Body6SUPP", prop: "tracked01", weap: "Cannon2A-TMk1" },
 commrl: { body: "Body6SUPP", prop: "HalfTrack", weap: "Rocket-MRL" },
 commrp: { body: "Body6SUPP", prop: "tracked01", weap: "Rocket-Pod" },
 comorb: { body: "Body6SUPP", prop: "HalfTrack", weap: "Mortar2Mk1" },
@@ -111,10 +112,14 @@ comsensh: { body: "Body6SUPP", prop: "HalfTrack", weap: "SensorTurret1Mk1" },
 
 // SUB_2_7
 comrotmh: { body: "Body6SUPP", prop: "tracked01", weap: "Mortar3ROTARYMk1" },
+comltath: { body: "Body6SUPP", prop: "hover01", weap: "Rocket-HvyA-T" },
 
 // SUB_2_8
 comhvat: { body: "Body6SUPP", prop: "V-Tol", weap: "Rocket-VTOL-HvyA-T" },
 
+// CAM_2_END
+cowwt: { body: "Body9REC", prop: "tracked01", weap: "QuadRotAAGun" },
+
 // CAM_3_A
 nxmscouh: { body: "Body7ABT", prop: "hover02", weap: "Missile-A-T" },
 nxcyrail: { body: "CybNXRail1Jmp", prop: "CyborgLegs02", weap: "NX-Cyb-Rail1" },
