@@ -2,10 +2,10 @@ function eventGameInit()
 {
 	//From script/rules/setupgame.js
 	setupGame();
-	
+
 	//From script/rules/printsettings.js
 	printGameSettings();
-	
+
 	//From script/rules/oildrum.js
 	oilDrumInit();
 
@@ -15,29 +15,29 @@ function eventGameInit()
 	//From script/setup/setupscavenger.js
 	setupScavenger();
 
-	for (var playnum = 0; playnum < maxPlayers; playnum++)
+	for (let playnum = 0; playnum < maxPlayers; ++playnum)
 	{
 		//From script/setup/powermodifier.js
 		setupPowerModifier(playnum);
-		
+
 		//From script/setup/droidlimit.js
 		droidLimit(playnum);
 
 		//From script/setup/setupstructure.js
 		setupStructure(playnum);
-		
+
 		//From script/setup/setupstructurelimit.js
 		setupStructureLimit(playnum);
-		
+
 		//From script/setup/setupresearch.js
 		setupResearch(playnum);
-		
+
 		//From script/setup/setupcomponents.js
 		setupComponents(playnum);
-		
+
 		//From script/setup/setupbase.js
 		setupBase(playnum);
-		
+
 		//From script/setup/setuptechlevels.js
 		setupTechLevel(playnum);
 
