@@ -38,6 +38,7 @@
 
 #if defined(WZ_OS_LINUX) && defined(__GLIBC__)
 #include <execinfo.h>  // Nonfatal runtime backtraces.
+#include <cxxabi.h>
 #endif // defined(WZ_OS_LINUX) && defined(__GLIBC__)
 
 #if defined(WZ_OS_UNIX)
@@ -54,7 +55,7 @@
 # include <stdio.h>
 #endif
 
-#define MAX_LEN_LOG_LINE 512
+#define MAX_LEN_LOG_LINE 1024
 
 char last_called_script_event[MAX_EVENT_NAME_LEN];
 UDWORD traceID = -1;
@@ -110,6 +111,7 @@ static const char *code_part_names[] =
 	"activity",
 	"research",
 	"savegame",
+	"repairs",
 	"last"
 };
 
@@ -145,7 +147,7 @@ static code_part code_part_from_str(const char *str)
  * \param	data			Ignored. Use NULL.
  * \param	outputBuffer	Buffer containing the preprocessed text to output.
  */
-void debug_callback_stderr(WZ_DECL_UNUSED void **data, const char *outputBuffer)
+void debug_callback_stderr(WZ_DECL_UNUSED void **data, const char *outputBuffer, code_part)
 {
 	if (outputBuffer[strlen(outputBuffer) - 1] != '\n')
 	{
@@ -170,8 +172,8 @@ void debug_callback_stderr(WZ_DECL_UNUSED void **data, const char *outputBuffer)
  * \param	data			Ignored. Use NULL.
  * \param	outputBuffer	Buffer containing the preprocessed text to output.
  */
-#if defined WIN32 && defined DEBUG
-void debug_callback_win32debug(WZ_DECL_UNUSED void **data, const char *outputBuffer)
+#if defined(_WIN32) && defined(DEBUG)
+void debug_callback_win32debug(WZ_DECL_UNUSED void **data, const char *outputBuffer, code_part)
 {
 	char tmpStr[MAX_LEN_LOG_LINE];
 
@@ -192,7 +194,7 @@ void debug_callback_win32debug(WZ_DECL_UNUSED void **data, const char *outputBuf
  * \param	data			Filehandle to output to.
  * \param	outputBuffer	Buffer containing the preprocessed text to output.
  */
-void debug_callback_file(void **data, const char *outputBuffer)
+void debug_callback_file(void **data, const char *outputBuffer, code_part)
 {
 	FILE *logfile = (FILE *)*data;
 
@@ -301,7 +303,7 @@ void debugFlushStderr()
 	debug_flush_stderr = true;
 }
 // MSVC specific rotuines to set/clear allocation tracking
-#if defined(WZ_CC_MSVC) && defined(DEBUG)
+#if defined(_MSC_VER) && defined(DEBUG)
 void debug_MEMCHKOFF()
 {
 	// Disable allocation tracking
@@ -428,14 +430,14 @@ bool debug_enable_switch(const char *str)
  *
  *  @param str The string to send to debug callbacks.
  */
-static void printToDebugCallbacks(const char *const str)
+static void printToDebugCallbacks(const char *const str, code_part part)
 {
 	debug_callback *curCallback;
 
 	// Loop over all callbacks, invoking them with the given data string
 	for (curCallback = callbackRegistry; curCallback != nullptr; curCallback = curCallback->next)
 	{
-		curCallback->callback(&curCallback->data, str);
+		curCallback->callback(&curCallback->data, str, part);
 	}
 }
 
@@ -450,7 +452,7 @@ void _realObjTrace(int id, const char *function, const char *str, ...)
 	va_end(ap);
 
 	ssprintf(outputBuffer, "[%6d]: [%s] %s", id, function, vaBuffer);
-	printToDebugCallbacks(outputBuffer);
+	printToDebugCallbacks(outputBuffer, LOG_INFO);
 }
 
 // Thread local to prevent a race condition on read and write to this buffer if multiple
@@ -515,7 +517,7 @@ void _debug(int line, code_part part, const char *function, const char *str, ...
 			{
 				ssprintf(outputBuffer, "last message repeated %u times", repeated - prev);
 			}
-			printToDebugCallbacks(outputBuffer);
+			printToDebugCallbacks(outputBuffer, part);
 			prev = repeated;
 			next *= 2;
 		}
@@ -534,7 +536,7 @@ void _debug(int line, code_part part, const char *function, const char *str, ...
 			{
 				ssprintf(outputBuffer, "last message repeated %u times", repeated - prev);
 			}
-			printToDebugCallbacks(outputBuffer);
+			printToDebugCallbacks(outputBuffer, part);
 		}
 		repeated = 0;
 		next = 2;
@@ -554,7 +556,7 @@ void _debug(int line, code_part part, const char *function, const char *str, ...
 		// Assemble the outputBuffer:
 		ssprintf(outputBuffer, "%-8s|%s: %s", code_part_names[part], ourtime, useInputBuffer1 ? inputBuffer[1] : inputBuffer[0]);
 
-		printToDebugCallbacks(outputBuffer);
+		printToDebugCallbacks(outputBuffer, part);
 
 		if (part == LOG_ERROR)
 		{
@@ -571,12 +573,12 @@ void _debug(int line, code_part part, const char *function, const char *str, ...
 				wzChangeWindowMode(WINDOW_MODE::windowed);
 			}
 #if defined(WZ_OS_WIN)
-			char wbuf[1024];
+			char wbuf[MAX_LEN_LOG_LINE+512];
 			ssprintf(wbuf, "%s\n\nPlease check the file (%s) in your configuration directory for more details. \
 				\nDo not forget to upload the %s file, WZdebuginfo.txt and the warzone2100.rpt files in your bug reports at https://github.com/Warzone2100/warzone2100/issues/new!", useInputBuffer1 ? inputBuffer[1] : inputBuffer[0], WZ_DBGFile, WZ_DBGFile);
 			wzDisplayDialog(Dialog_Error, "Warzone has terminated unexpectedly", wbuf);
 #elif defined(WZ_OS_MAC)
-			char wbuf[1024];
+			char wbuf[MAX_LEN_LOG_LINE+128];
 			ssprintf(wbuf, "%s\n\nPlease check your logs and attach them along with a bug report. Thanks!", useInputBuffer1 ? inputBuffer[1] : inputBuffer[0]);
 			int clickedIndex = \
 			                   cocoaShowAlert("Warzone has quit unexpectedly.",
@@ -631,9 +633,33 @@ void _debugBacktrace(code_part part)
 	unsigned num = backtrace(btv, sizeof(btv) / sizeof(*btv));
 	char **btc = backtrace_symbols(btv, num);
 	unsigned i;
-	for (i = 1; i + 2 < num; ++i)  // =1: Don't print "src/warzone2100(syncDebugBacktrace+0x16) [0x6312d1]". +2: Don't print last two lines of backtrace such as "/lib/libc.so.6(__libc_start_main+0xe6) [0x7f91e040ea26]", since the address varies (even with the same binary).
+	auto trim = [](const char *in, char *out) {
+		const char *begin = strchr(in, '_');
+		if (begin)
+		{
+			const char *end = strchr(begin, '+');
+			if (end)
+			{
+				memcpy(out, begin, end - begin);
+				out[end - begin] = '\0';
+			}
+		}
+	};
+	for (i = 1; i + 2 < num; ++i) 
 	{
-		_debug(0, part, "BT", "%s", btc[i]);
+		int status = -1;
+		char buf[1024];
+		const char *p = btc[i];
+		trim(p, buf);
+		char *readableName = abi::__cxa_demangle(buf, NULL, NULL, &status);
+		if (status == 0)
+		{
+			_debug(0, part, "BT", "%s", readableName);
+		}
+		else
+		{
+			_debug(0, part, "BT", "%s [status: %i]", btc[i], status);
+		}
 	}
 	free(btc);
 #else
