@@ -30,6 +30,10 @@
 # include <CoreFoundation/CFURL.h>
 #endif
 
+#include <nonstd/optional.hpp>
+using nonstd::optional;
+using nonstd::nullopt;
+
 /* Always use fallbacks on Windows */
 #if defined(WZ_OS_WIN)
 #  undef LOCALEDIR
@@ -46,6 +50,7 @@
 #  endif
 #endif
 // Language names (http://en.wikipedia.org/wiki/List_of_ISO_639-2_codes)
+#define LANG_NAME_ARABIC "العربية"
 #define LANG_NAME_BASQUE "euskara"
 #define LANG_NAME_BULGARIAN "български език"
 #define LANG_NAME_CATALAN "català"
@@ -97,25 +102,27 @@ static const struct
 {
 	const char *language;
 	const char *name;
+	const char *localeFilename; // the actual filename on disk, minus the extension (ex. "en_GB")
 	USHORT usPrimaryLanguage;
 	USHORT usSubLanguage;
 } map[] =
 {
-	{ "", N_("System locale"), LANG_NEUTRAL, SUBLANG_DEFAULT },
+	{ "", N_("System locale"), "", LANG_NEUTRAL, SUBLANG_DEFAULT },
 #  if defined(ENABLE_NLS)
-	{ "bg", LANG_NAME_BULGARIAN, LANG_BULGARIAN, SUBLANG_DEFAULT },
-	{ "ca", LANG_NAME_CATALAN, LANG_CATALAN, SUBLANG_DEFAULT },
-	{ "cs", LANG_NAME_CZECH, LANG_CZECH, SUBLANG_DEFAULT },
-	{ "da", LANG_NAME_DANISH, LANG_DANISH, SUBLANG_DEFAULT },
-	{ "de", LANG_NAME_GERMAN, LANG_GERMAN, SUBLANG_GERMAN },
-	{ "el", LANG_NAME_GREEK, LANG_GREEK, SUBLANG_DEFAULT },
-	{ "en", LANG_NAME_ENGLISH, LANG_ENGLISH, SUBLANG_DEFAULT },
-	{ "en_GB", LANG_NAME_ENGLISH_UK, LANG_ENGLISH, SUBLANG_ENGLISH_UK },
-	{ "es", LANG_NAME_SPANISH, LANG_SPANISH, SUBLANG_SPANISH },
-	{ "et_EE", LANG_NAME_ESTONIAN, LANG_ESTONIAN, SUBLANG_DEFAULT },
+	{ "ar_SA", LANG_NAME_ARABIC, "ar_SA", LANG_ARABIC, SUBLANG_DEFAULT },
+	{ "bg", LANG_NAME_BULGARIAN, "bg_BG", LANG_BULGARIAN, SUBLANG_DEFAULT },
+	{ "ca_ES", LANG_NAME_CATALAN, "ca_ES", LANG_CATALAN, SUBLANG_DEFAULT },
+	{ "cs_CZ", LANG_NAME_CZECH, "cs", LANG_CZECH, SUBLANG_DEFAULT },
+	{ "da", LANG_NAME_DANISH, "da", LANG_DANISH, SUBLANG_DEFAULT },
+	{ "de", LANG_NAME_GERMAN, "de", LANG_GERMAN, SUBLANG_GERMAN },
+	{ "el_GR", LANG_NAME_GREEK, "el", LANG_GREEK, SUBLANG_DEFAULT },
+	{ "en", LANG_NAME_ENGLISH, "en", LANG_ENGLISH, SUBLANG_DEFAULT },
+	{ "en_GB", LANG_NAME_ENGLISH_UK, "en_GB", LANG_ENGLISH, SUBLANG_ENGLISH_UK },
+	{ "es", LANG_NAME_SPANISH, "es", LANG_SPANISH, SUBLANG_SPANISH },
+	{ "et_EE", LANG_NAME_ESTONIAN, "et_EE", LANG_ESTONIAN, SUBLANG_DEFAULT },
 //	{ "eu", LANG_NAME_BASQUE, LANG_BASQUE, SUBLANG_DEFAULT },
-	{ "fi", LANG_NAME_FINNISH, LANG_FINNISH, SUBLANG_DEFAULT },
-	{ "fr", LANG_NAME_FRENCH, LANG_FRENCH, SUBLANG_FRENCH },
+	{ "fi", LANG_NAME_FINNISH, "fi", LANG_FINNISH, SUBLANG_DEFAULT },
+	{ "fr", LANG_NAME_FRENCH, "fr", LANG_FRENCH, SUBLANG_FRENCH },
 	/* Our Frisian translation is the "West Frisian" variation of it. This
 	 * variation is mostly spoken in the Dutch province Friesland (Fryslân
 	 * in Frisian) and has ISO 639-3 code "fry".
@@ -123,38 +130,38 @@ static const struct
 	 * FIXME: We should really use a sub-language code for this. E.g.
 	 *        fy_XX.
 	 */
-	{ "fy", LANG_NAME_FRISIAN_NETHERLANDS, LANG_FRISIAN, SUBLANG_FRISIAN_NETHERLANDS },
-	{ "ga", LANG_NAME_IRISH, LANG_IRISH, SUBLANG_IRISH_IRELAND },
-	{ "hr", LANG_NAME_CROATIAN, LANG_CROATIAN, SUBLANG_DEFAULT },
-	{ "hu", LANG_NAME_HUNGARIAN, LANG_HUNGARIAN, SUBLANG_DEFAULT },
-	{ "id", LANG_NAME_INDONESIAN, LANG_INDONESIAN, SUBLANG_DEFAULT },
-	{ "it", LANG_NAME_ITALIAN, LANG_ITALIAN, SUBLANG_ITALIAN },
-	{ "ko_KR", LANG_NAME_KOREAN, LANG_KOREAN, SUBLANG_DEFAULT },
-//	{ "la", LANG_NAME_LATIN, LANG_LATIN, SUBLANG_DEFAULT },
-	{ "lt", LANG_NAME_LITHUANIAN, LANG_LITHUANIAN, SUBLANG_DEFAULT },
+	{ "fy_NL", LANG_NAME_FRISIAN_NETHERLANDS, "fy", LANG_FRISIAN, SUBLANG_FRISIAN_NETHERLANDS },
+	{ "ga_IE", LANG_NAME_IRISH, "ga", LANG_IRISH, SUBLANG_IRISH_IRELAND },
+	{ "hr", LANG_NAME_CROATIAN, "hr", LANG_CROATIAN, SUBLANG_DEFAULT },
+	{ "hu", LANG_NAME_HUNGARIAN, "hu", LANG_HUNGARIAN, SUBLANG_DEFAULT },
+	{ "id", LANG_NAME_INDONESIAN, "id_ID", LANG_INDONESIAN, SUBLANG_DEFAULT },
+	{ "it", LANG_NAME_ITALIAN, "it", LANG_ITALIAN, SUBLANG_ITALIAN },
+	{ "ko_KR", LANG_NAME_KOREAN, "ko", LANG_KOREAN, SUBLANG_DEFAULT },
+//	{ "la", LANG_NAME_LATIN, "la", LANG_LATIN, SUBLANG_DEFAULT },
+	{ "lt", LANG_NAME_LITHUANIAN, "lt", LANG_LITHUANIAN, SUBLANG_DEFAULT },
 //	{ "lv", LANG_NAME_LATVIAN, LANG_LATVIAN, SUBLANG_DEFAULT },
 	// MSDN uses "no"...
-	{ "nb", LANG_NAME_NORWEGIAN, LANG_NORWEGIAN, SUBLANG_DEFAULT },
+	{ "nb_NO", LANG_NAME_NORWEGIAN, "nb", LANG_NORWEGIAN, SUBLANG_DEFAULT },
 //	{ "nn", LANG_NAME_NORWEGIAN_NYNORSK, LANG_NORWEGIAN, SUBLANG_NORWEGIAN_NYNORSK },
-	{ "nl", LANG_NAME_DUTCH, LANG_DUTCH, SUBLANG_DUTCH },
-	{ "pl", LANG_NAME_POLISH, LANG_POLISH, SUBLANG_DEFAULT },
-	{ "pt_BR", LANG_NAME_PORTUGUESE_BRAZILIAN, LANG_PORTUGUESE, SUBLANG_PORTUGUESE_BRAZILIAN },
-	{ "pt", LANG_NAME_PORTUGUESE, LANG_PORTUGUESE, SUBLANG_DEFAULT },
-	{ "ro", LANG_NAME_ROMANIAN, LANG_ROMANIAN, SUBLANG_DEFAULT },
-	{ "ru", LANG_NAME_RUSSIAN, LANG_RUSSIAN, SUBLANG_DEFAULT },
-	{ "sk", LANG_NAME_SLOVAK, LANG_SLOVAK, SUBLANG_DEFAULT },
-	{ "sl", LANG_NAME_SLOVENIAN, LANG_SLOVENIAN, SUBLANG_DEFAULT },
+	{ "nl", LANG_NAME_DUTCH, "nl", LANG_DUTCH, SUBLANG_DUTCH },
+	{ "pl", LANG_NAME_POLISH, "pl", LANG_POLISH, SUBLANG_DEFAULT },
+	{ "pt_BR", LANG_NAME_PORTUGUESE_BRAZILIAN, "pt_BR", LANG_PORTUGUESE, SUBLANG_PORTUGUESE_BRAZILIAN },
+	{ "pt", LANG_NAME_PORTUGUESE, "pt", LANG_PORTUGUESE, SUBLANG_DEFAULT },
+	{ "ro", LANG_NAME_ROMANIAN, "ro", LANG_ROMANIAN, SUBLANG_DEFAULT },
+	{ "ru", LANG_NAME_RUSSIAN, "ru", LANG_RUSSIAN, SUBLANG_DEFAULT },
+	{ "sk", LANG_NAME_SLOVAK, "sk", LANG_SLOVAK, SUBLANG_DEFAULT },
+	{ "sl_SI", LANG_NAME_SLOVENIAN, "sl", LANG_SLOVENIAN, SUBLANG_DEFAULT },
 #if (WINVER >= 0x0600)
 //	{ "sv_SE", LANG_NAME_SWEDISH_SWEDEN, LANG_SWEDISH, SUBLANG_SWEDISH_SWEDEN },
 #else
 //	{ "sv_SE", LANG_NAME_SWEDISH_SWEDEN, LANG_SWEDISH, SUBLANG_SWEDISH },
 #endif
 //	{ "sv", LANG_NAME_SWEDISH, LANG_SWEDISH, SUBLANG_DEFAULT },
-	{ "tr", LANG_NAME_TURKISH, LANG_TURKISH, SUBLANG_DEFAULT },
+	{ "tr", LANG_NAME_TURKISH, "tr", LANG_TURKISH, SUBLANG_DEFAULT },
 //	{ "uz", LANG_NAME_UZBEK_CYRILLIC, LANG_UZBEK, SUBLANG_UZBEK_CYRILLIC },
-	{ "uk_UA", LANG_NAME_UKRAINIAN, LANG_UKRAINIAN, SUBLANG_DEFAULT },
-	{ "zh_CN", LANG_NAME_CHINESE_SIMPLIFIED, LANG_CHINESE, SUBLANG_CHINESE_SIMPLIFIED },
-	{ "zh_TW", LANG_NAME_CHINESE_TRADITIONAL, LANG_CHINESE, SUBLANG_CHINESE_TRADITIONAL },
+	{ "uk_UA", LANG_NAME_UKRAINIAN, "uk_UA", LANG_UKRAINIAN, SUBLANG_DEFAULT },
+	{ "zh_CN", LANG_NAME_CHINESE_SIMPLIFIED, "zh_CN", LANG_CHINESE, SUBLANG_CHINESE_SIMPLIFIED },
+	{ "zh_TW", LANG_NAME_CHINESE_TRADITIONAL, "zh_TW", LANG_CHINESE, SUBLANG_CHINESE_TRADITIONAL },
 #  endif
 };
 #else
@@ -162,63 +169,66 @@ static const struct
 {
 	const char *language;
 	const char *name;
+	const char *localeFilename; // the actual filename on disk, minus the extension (ex. "en_GB")
 	const char *locale;
 	const char *localeFallback;
 } map[] =
 {
-	{ "",   N_("System locale"), "", "" },
+	{ "",   N_("System locale"), "", "", "" },
 #  if defined(ENABLE_NLS)
-	{ "bg", LANG_NAME_BULGARIAN, "bg_BG.UTF-8", "bg" },
-	{ "ca_ES", LANG_NAME_CATALAN, "ca_ES.UTF-8", "ca" },
-	{ "cs_CZ", LANG_NAME_CZECH, "cs_CZ.UTF-8", "cs" },
-	{ "da", LANG_NAME_DANISH, "da_DK.UTF-8", "da_DK" },
-	{ "de", LANG_NAME_GERMAN, "de_DE.UTF-8", "de_DE" },
-	{ "el_GR", LANG_NAME_GREEK, "el_GR.UTF-8", "el" },
-	{ "en", LANG_NAME_ENGLISH, "en_US.UTF-8", "en_US" },
-	{ "en_GB", LANG_NAME_ENGLISH_UK, "en_GB.UTF-8", "en_GB" },
-	{ "es", LANG_NAME_SPANISH, "es_ES.UTF-8", "es_ES" },
-	{ "et_EE", LANG_NAME_ESTONIAN, "et_EE.UTF-8", "et" },
+	{ "ar_SA", LANG_NAME_ARABIC, "ar_SA", "ar_SA.UTF-8", "ar"},
+	{ "bg", LANG_NAME_BULGARIAN, "bg_BG", "bg_BG.UTF-8", "bg" },
+	{ "ca_ES", LANG_NAME_CATALAN, "ca_ES", "ca_ES.UTF-8", "ca" },
+	{ "cs_CZ", LANG_NAME_CZECH, "cs", "cs_CZ.UTF-8", "cs" },
+	{ "da", LANG_NAME_DANISH, "da", "da_DK.UTF-8", "da_DK" },
+	{ "de", LANG_NAME_GERMAN, "de", "de_DE.UTF-8", "de_DE" },
+	{ "el_GR", LANG_NAME_GREEK, "el", "el_GR.UTF-8", "el" },
+	{ "en", LANG_NAME_ENGLISH, "en", "en_US.UTF-8", "en_US" },
+	{ "en_GB", LANG_NAME_ENGLISH_UK, "en_GB", "en_GB.UTF-8", "en_GB" },
+	{ "es", LANG_NAME_SPANISH, "es", "es_ES.UTF-8", "es_ES" },
+	{ "et_EE", LANG_NAME_ESTONIAN, "et_EE", "et_EE.UTF-8", "et" },
 //	{ "eu_ES", LANG_NAME_BASQUE, "eu_ES.UTF-8", "eu" },
-	{ "fi", LANG_NAME_FINNISH, "fi_FI.UTF-8", "fi_FI" },
-	{ "fr", LANG_NAME_FRENCH, "fr_FR.UTF-8", "fr_FR" },
+	{ "fi", LANG_NAME_FINNISH, "fi", "fi_FI.UTF-8", "fi_FI" },
+	{ "fr", LANG_NAME_FRENCH, "fr", "fr_FR.UTF-8", "fr_FR" },
 	/* Our Frisian translation is the "West Frisian" variation of it. This
 	 * variation is mostly spoken in the Dutch province Friesland (Fryslân
 	 * in Frisian) and has ISO 639-3 code "fry".
 	 */
-	{ "fy_NL", LANG_NAME_FRISIAN_NETHERLANDS, "fy_NL.UTF-8", "fy" },
-	{ "ga_IE", LANG_NAME_IRISH, "ga_IE.UTF-8", "ga" },
-	{ "hr", LANG_NAME_CROATIAN, "hr_HR.UTF-8", "hr_HR" },
-	{ "hu", LANG_NAME_HUNGARIAN, "hu_HU.UTF-8", "hu_HU" },
-	{ "id", LANG_NAME_INDONESIAN, "id_ID.UTF-8", "id" },
-	{ "it", LANG_NAME_ITALIAN, "it_IT.UTF-8", "it_IT" },
-	{ "ko_KR", LANG_NAME_KOREAN, "ko_KR.UTF-8", "ko" },
-	{ "la", LANG_NAME_LATIN, "la.UTF-8", "la" },
-	{ "lt", LANG_NAME_LITHUANIAN, "lt_LT.UTF-8", "lt_LT" },
+	{ "fy_NL", LANG_NAME_FRISIAN_NETHERLANDS, "fy", "fy_NL.UTF-8", "fy" },
+	{ "ga_IE", LANG_NAME_IRISH, "ga", "ga_IE.UTF-8", "ga" },
+	{ "hr", LANG_NAME_CROATIAN, "hr", "hr_HR.UTF-8", "hr_HR" },
+	{ "hu", LANG_NAME_HUNGARIAN, "hu", "hu_HU.UTF-8", "hu_HU" },
+	{ "id", LANG_NAME_INDONESIAN, "id_ID", "id_ID.UTF-8", "id" },
+	{ "it", LANG_NAME_ITALIAN, "it", "it_IT.UTF-8", "it_IT" },
+	{ "ko_KR", LANG_NAME_KOREAN, "ko", "ko_KR.UTF-8", "ko" },
+	{ "la", LANG_NAME_LATIN, "la", "la.UTF-8", "la" },
+	{ "lt", LANG_NAME_LITHUANIAN, "lt", "lt_LT.UTF-8", "lt_LT" },
 //	{ "lv", LANG_NAME_LATVIAN, "lv_LV.UTF-8", "lv_LV" },
-	{ "nb_NO", LANG_NAME_NORWEGIAN, "nb_NO.UTF-8", "nb" },
+	{ "nb_NO", LANG_NAME_NORWEGIAN, "nb", "nb_NO.UTF-8", "nb" },
 //	{ "nn_NO", LANG_NAME_NORWEGIAN_NYNORSK, "nn_NO.UTF-8", "nn" },
-	{ "nl", LANG_NAME_DUTCH, "nl_NL.UTF-8", "nl_NL" },
-	{ "pl", LANG_NAME_POLISH, "pl_PL.UTF-8", "pl_PL" },
-	{ "pt_BR", LANG_NAME_PORTUGUESE_BRAZILIAN, "pt_BR.UTF-8", "pt_BR" },
-	{ "pt", LANG_NAME_PORTUGUESE, "pt_PT.UTF-8", "pt_PT" },
-	{ "ro", LANG_NAME_ROMANIAN, "ro_RO.UTF-8", "ro_RO" },
-	{ "ru", LANG_NAME_RUSSIAN, "ru_RU.UTF-8", "ru_RU" },
-	{ "sk", LANG_NAME_SLOVAK, "sk_SK.UTF-8", "sk_SK" },
-	{ "sl_SI", LANG_NAME_SLOVENIAN, "sl_SI.UTF-8", "sl" },
+	{ "nl", LANG_NAME_DUTCH, "nl", "nl_NL.UTF-8", "nl_NL" },
+	{ "pl", LANG_NAME_POLISH, "pl", "pl_PL.UTF-8", "pl_PL" },
+	{ "pt_BR", LANG_NAME_PORTUGUESE_BRAZILIAN, "pt_BR", "pt_BR.UTF-8", "pt_BR" },
+	{ "pt", LANG_NAME_PORTUGUESE, "pt", "pt_PT.UTF-8", "pt_PT" },
+	{ "ro", LANG_NAME_ROMANIAN, "ro", "ro_RO.UTF-8", "ro_RO" },
+	{ "ru", LANG_NAME_RUSSIAN, "ru", "ru_RU.UTF-8", "ru_RU" },
+	{ "sk", LANG_NAME_SLOVAK, "sk", "sk_SK.UTF-8", "sk_SK" },
+	{ "sl_SI", LANG_NAME_SLOVENIAN, "sl", "sl_SI.UTF-8", "sl" },
 //	{ "sv_SE", LANG_NAME_SWEDISH_SWEDEN, "sv_SE.UTF-8", "sv" },
 //	{ "sv", LANG_NAME_SWEDISH, "sv.UTF-8", "sv" },
-	{ "tr", LANG_NAME_TURKISH, "tr_TR.UTF-8", "tr_TR" },
+	{ "tr", LANG_NAME_TURKISH, "tr", "tr_TR.UTF-8", "tr_TR" },
 //	{ "uz", LANG_NAME_UZBEK_CYRILLIC, "uz_UZ.UTF-8", "uz_UZ" },
-	{ "uk_UA", LANG_NAME_UKRAINIAN, "uk_UA.UTF-8", "uk" },
-	{ "zh_CN", LANG_NAME_CHINESE_SIMPLIFIED, "zh_CN.UTF-8", "zh_CN" },
-	{ "zh_TW", LANG_NAME_CHINESE_TRADITIONAL, "zh_TW.UTF-8", "zh_TW" },
+	{ "uk_UA", LANG_NAME_UKRAINIAN, "uk_UA", "uk_UA.UTF-8", "uk" },
+	{ "zh_CN", LANG_NAME_CHINESE_SIMPLIFIED, "zh_CN", "zh_CN.UTF-8", "zh_CN" },
+	{ "zh_TW", LANG_NAME_CHINESE_TRADITIONAL, "zh_TW", "zh_TW.UTF-8", "zh_TW" },
 #  endif
 };
 #endif
 
 static unsigned int selectedLanguage = 0;
+static bool canUseLANGUAGEEnvVar = false;
 
-static char *compileDate = nullptr;
+static std::string compileDate;
 
 /*!
  * Return the language part of the selected locale
@@ -329,42 +339,32 @@ static bool setLocaleWindows(USHORT usPrimaryLanguage, USHORT usSubLanguage)
  */
 static bool setLocaleUnix(const char *locale)
 {
-#ifdef WZ_OS_MAC
-	// Set the appropriate language environment variable *before* the call to libintl's `setlocale`.
+	const char *pEnvLang = nullptr;
 
-	// First, check if LC_ALL or LC_MESSAGES is set, as these may override LANG
-	const char *pEnvLang = getenv("LC_ALL");
-	if ((pEnvLang != nullptr) && (pEnvLang[0] != '\0'))
-	{
-		debug(LOG_WARNING, "Environment variable \"LC_ALL\" is set, and may override runtime language changes.");
-	}
-	pEnvLang = getenv("LC_MESSAGES");
-	if ((pEnvLang != nullptr) && (pEnvLang[0] != '\0'))
-	{
-		debug(LOG_WARNING, "Environment variable \"LC_MESSAGES\" is set, and may override runtime language changes.");
-	}
-
-	// Set the LANG env-var (temporarily saving the old value)
+	// Set the appropriate language environment variables *before* the call to libintl's `setlocale`.
+	// (The LANGUAGE and LANG env-vars) (temporarily saving the old values)
+	// This is *REQUIRED* on some platforms where other environment variables (LC_ALL, LC_MESSAGES, etc) are sometimes set (ex. macOS), or run-time language switching won't work
+	pEnvLang = getenv("LANGUAGE");
+	std::string prior_LANGUAGE((pEnvLang != nullptr) ? pEnvLang : "");
 	pEnvLang = getenv("LANG");
 	std::string prior_LANG((pEnvLang != nullptr) ? pEnvLang : "");
-#  if defined HAVE_SETENV
+#if defined(HAVE_SETENV)
+	setenv("LANGUAGE", locale, 1);
 	setenv("LANG", locale, 1);
-#  else
+#else
 	# warning "No supported method to set environment variables"
-#  endif
-#endif // (ifdef WZ_OS_MAC)
+#endif
 
 	const char *actualLocale = setlocale(LC_ALL, locale);
 
 	if (actualLocale == NULL)
 	{
 		wz_info("Failed to set locale to \"%s\"", locale);
-#ifdef WZ_OS_MAC
-#  if defined HAVE_SETENV
+#if defined(HAVE_SETENV)
+		setenv("LANGUAGE", prior_LANGUAGE.c_str(), 1);
 		setenv("LANG", prior_LANG.c_str(), 1);
-#  else
+#else
 		# warning "No supported method to set environment variables"
-#  endif
 #endif
 	}
 	else
@@ -380,6 +380,32 @@ static bool setLocaleUnix(const char *locale)
 
 	return (actualLocale != NULL);
 }
+static bool setLocaleUnix_LANGUAGEFallback(const char *localeFilename)
+{
+	if (!canUseLANGUAGEEnvVar)
+	{
+		return false;
+	}
+#if defined(HAVE_SETENV) // or possibly other methods in the future?
+	const char *pEnvLang = getenv("LANGUAGE");
+	std::string prior_LANGUAGE((pEnvLang != nullptr) ? pEnvLang : "");
+
+	setlocale(LC_ALL, ""); // use default system locale
+
+#if defined(HAVE_SETENV)
+	setenv("LANGUAGE", localeFilename, 1); // libintl will pick this up and use this preferentially
+#else
+	# warning "No supported method to set environment variables"
+#endif
+
+	const char * numericLocale = setlocale(LC_NUMERIC, "C"); // set radix character to the period (".")
+	debug(LOG_WZ, "LC_NUMERIC: \"%s\"", (numericLocale != nullptr) ? numericLocale : "<null>");
+
+	return true;
+#else // defined(HAVE_SETENV)
+	return false;
+#endif // defined(HAVE_SETENV)
+}
 #  endif
 #endif
 
@@ -401,7 +427,7 @@ bool setLanguage(const char *language)
 #  if defined(WZ_OS_WIN)
 			return setLocaleWindows(map[i].usPrimaryLanguage, map[i].usSubLanguage);
 #  else
-			return setLocaleUnix(map[i].locale) || setLocaleUnix(map[i].localeFallback);
+			return setLocaleUnix(map[i].locale) || setLocaleUnix(map[i].localeFallback) || setLocaleUnix_LANGUAGEFallback(map[i].localeFilename);
 #  endif
 		}
 	}
@@ -412,19 +438,21 @@ bool setLanguage(const char *language)
 #endif
 }
 
-
-void setNextLanguage(bool prev)
+std::vector<locale_info> getLocales()
 {
-	selectedLanguage = (selectedLanguage + ARRAY_SIZE(map) + (prev? -1 : 1)) % ARRAY_SIZE(map);
-
-	if (!setLanguage(map[selectedLanguage].language) && selectedLanguage != 0)
+	std::vector<locale_info> locales;
+	for (const auto &entry: map)
 	{
-		setNextLanguage(prev); // try next
+		locales.push_back({entry.language, entry.name});
 	}
+
+	return locales;
 }
 
 std::string wzBindTextDomain(const char *domainname, const char *dirname)
 {
+	debug(LOG_WZ, "bindTextDomain(%s, %s)", (domainname) ? domainname : "NULL", (dirname) ? dirname : "NULL");
+
 #if (LIBINTL_VERSION >= 0x001500) && defined(_WIN32) && !defined(__CYGWIN__)
 	// gettext 0.21+ provides a wbindtextdomain function on native Windows platforms
 	// that properly supports Unicode paths
@@ -483,15 +511,66 @@ std::string wzBindTextDomain(const char *domainname, const char *dirname)
 #endif
 }
 
+static bool checkSupportsLANGUAGEenvVarOverride()
+{
+#if defined(_LIBINTL_H) && defined(LIBINTL_VERSION)
+	// Only known to be supported by GNU Gettext runtime (libintl) behavior
+	// GNU Gettext permits overriding with the "LANGUAGE" environment variable to specify the language for messages
+	// As long as the current locale does not equal the "plain" C locale (i.e. just "C")
+
+	debug(LOG_WZ, "Checking for support of LANGUAGE env var override");
+
+# if defined(WZ_OS_WIN)
+	// NOTE: Not currently supported on Windows because we take advantage of GNU Gettext's gl_locale_name fall-back to GetThreadLocale()
+	//		 But if we call setlocale and set values, it won't fall-back.
+	return false;
+
+# else // !defined(WZ_OS_WIN)
+
+	optional<std::string> prevLocale;
+	const char *actualLocale = setlocale(LC_MESSAGES, NULL);
+	if (actualLocale != NULL)
+	{
+		prevLocale = actualLocale;
+	}
+
+	// Try to set "default" locale
+	actualLocale = setlocale(LC_MESSAGES, "");
+	if (actualLocale == NULL)
+	{
+		// Failed
+		return false;
+	}
+
+	// Can only use LANGUAGE override if the locale is *not* plain "C"
+	bool result = !(strcmp(actualLocale, "C") == 0);
+
+	if (prevLocale.has_value())
+	{
+		// reset back to prev locale before test
+		setlocale(LC_MESSAGES, prevLocale.value().c_str());
+	}
+
+	debug(LOG_WZ, "Supports LANGUAGE env var override: %s", (result) ? "YES" : "no");
+	return result;
+# endif // defined(WZ_OS_WIN)
+#else
+	debug(LOG_WZ, "No support for LANGUAGE env var override (not GNU gettext?)");
+	return false;
+#endif // defined(_LIBINTL_H) && defined(LIBINTL_VERSION)
+}
+
 void initI18n()
 {
 	std::string textdomainDirectory;
 
-	if (!setLanguage("")) // set to system default
-	{
-		// no system default?
-		debug(LOG_ERROR, "initI18n: No system language found");
-	}
+#if defined(_LIBINTL_H) && defined(LIBINTL_VERSION)
+	int wz_libintl_maj = LIBINTL_VERSION >> 16;
+	int wz_libintl_min = (LIBINTL_VERSION >> 8) & 0xFF;
+	int wz_libintl_rev = LIBINTL_VERSION & 0xFF;
+	debug(LOG_WZ, "libintl version: %d.%d.%d", wz_libintl_maj, wz_libintl_min, wz_libintl_rev);
+#endif
+
 #ifdef WZ_OS_MAC
 	{
 		char resourcePath[PATH_MAX];
@@ -519,6 +598,7 @@ void initI18n()
 	#ifndef WZ_LOCALEDIR_ISABSOLUTE
 	// Treat WZ_LOCALEDIR as a relative path - append to the install PREFIX
 	const std::string prefixDir = getWZInstallPrefix();
+	debug(LOG_WZ, "Install prefix: %s", prefixDir.c_str());
 	const std::string dirSeparator(PHYSFS_getDirSeparator());
 	std::string localeDir = prefixDir + dirSeparator + WZ_LOCALEDIR;
 	textdomainDirectory = wzBindTextDomain(PACKAGE, localeDir.c_str());
@@ -538,12 +618,22 @@ void initI18n()
 
 	(void)bind_textdomain_codeset(PACKAGE, "UTF-8");
 	(void)textdomain(PACKAGE);
+	debug(LOG_WZ, "textdomain: %s", PACKAGE);
+
+	// Should come *after* bindTextDomain
+	canUseLANGUAGEEnvVar = checkSupportsLANGUAGEenvVarOverride();
+
+	if (!setLanguage("")) // set to system default
+	{
+		// no system default?
+		debug(LOG_ERROR, "initI18n: No system language found");
+	}
 }
 
 // convert macro __DATE__ to ISO 8601 format
 const char *getCompileDate()
 {
-	if (compileDate == nullptr)
+	if (compileDate.empty())
 	{
 		std::istringstream date(__DATE__);
 		std::string monthName;
@@ -563,7 +653,7 @@ const char *getCompileDate()
 				break;
 			}
 		}
-		asprintfNull(&compileDate, "%04d-%02d-%02d", year, month, day);
+		compileDate = astringf("%04d-%02d-%02d", year, month, day);
 	}
-	return compileDate;
+	return compileDate.c_str();
 }
