@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2019  Warzone 2100 Project
+	Copyright (C) 2005-2021  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
 #include <physfs.h>
 #include "file.h"
 #include <sstream>
+#include <limits>
+#include "physfs_ext.h"
 
 WzConfig::~WzConfig()
 {
@@ -36,7 +38,10 @@ WzConfig::~WzConfig()
 		std::ostringstream stream;
 		stream << mRoot.dump(4) << std::endl;
 		std::string jsonString = stream.str();
-		saveFile(mFilename.toUtf8().c_str(), jsonString.c_str(), jsonString.size());
+#if SIZE_MAX >= UDWORD_MAX
+		ASSERT(jsonString.size() <= static_cast<size_t>(std::numeric_limits<UDWORD>::max()), "jsonString.size (%zu) exceeds UDWORD::max", jsonString.size());
+#endif
+		saveFile(mFilename.toUtf8().c_str(), jsonString.c_str(), static_cast<UDWORD>(jsonString.size()));
 	}
 	debug(LOG_SAVE, "%s %s", mWarning == ReadAndWrite? "Saving" : "Closing", mFilename.toUtf8().c_str());
 }
@@ -66,8 +71,8 @@ static nlohmann::json jsonMerge(nlohmann::json original, const nlohmann::json& o
 WzConfig::WzConfig(const WzString &name, WzConfig::warning warning)
 : mArray(nlohmann::json::array())
 {
-	UDWORD size;
-	char *data;
+	UDWORD size = 0;
+	char *data = nullptr;
 
 	mFilename = name;
 	mStatus = true;
@@ -93,8 +98,11 @@ WzConfig::WzConfig(const WzString &name, WzConfig::warning warning)
 	}
 	if (!loadFile(name.toUtf8().c_str(), &data, &size))
 	{
+		mStatus = false;
 		debug(LOG_FATAL, "Could not open \"%s\"", name.toUtf8().c_str());
+		return;
 	}
+	ASSERT_OR_RETURN(, data != nullptr, "Null data?");
 
 	try {
 		mRoot = nlohmann::json::parse(data, data + size);
@@ -109,14 +117,14 @@ WzConfig::WzConfig(const WzString &name, WzConfig::warning warning)
 	ASSERT(!mRoot.is_null(), "JSON document from %s is null", name.toUtf8().c_str());
 	ASSERT(mRoot.is_object(), "JSON document from %s is not an object. Read: \n%s", name.toUtf8().c_str(), data);
 	free(data);
-	char **diffList = PHYSFS_enumerateFiles("diffs");
-	for (char **i = diffList; *i != nullptr; i++)
-	{
-		std::string str(std::string("diffs/") + *i + std::string("/") + name.toUtf8().c_str());
+	WZ_PHYSFS_enumerateFiles("diffs", [&](const char *i) -> bool {
+		std::string str(std::string("diffs/") + i + std::string("/") + name.toUtf8().c_str());
 		if (!PHYSFS_exists(str.c_str()))
 		{
-			continue;
+			return true; // continue;
 		}
+		UDWORD size = 0;
+		char *data = nullptr;
 		if (!loadFile(str.c_str(), &data, &size))
 		{
 			debug(LOG_FATAL, "jsondiff file \"%s\" could not be opened!", name.toUtf8().c_str());
@@ -136,8 +144,8 @@ WzConfig::WzConfig(const WzString &name, WzConfig::warning warning)
 		mRoot = jsonMerge(mRoot, tmpJson);
 		free(data);
 		debug(LOG_INFO, "jsondiff \"%s\" loaded and merged", str.c_str());
-	}
-	PHYSFS_freeList(diffList);
+		return true; // continue
+	});
 	debug(LOG_SAVE, "Opening %s", name.toUtf8().c_str());
 	pCurrentObj = &mRoot;
 }
@@ -199,6 +207,12 @@ nlohmann::json WzConfig::json(const WzString &key, const nlohmann::json &default
 	}
 }
 
+nlohmann::json& WzConfig::currentJsonValue() const
+{
+	ASSERT(pCurrentObj, "pCurrentObj is null");
+	return *pCurrentObj;
+}
+
 WzString WzConfig::string(const WzString &key, const WzString &defaultValue) const
 {
 	auto it = pCurrentObj->find(key.toUtf8());
@@ -236,9 +250,9 @@ Vector3f WzConfig::vector3f(const WzString &name)
 	auto v = it.value();
 	ASSERT(v.size() == 3, "%s: Bad list of %s", mFilename.toUtf8().c_str(), name.toUtf8().c_str());
 	try {
-		r.x = v[0];
-		r.y = v[1];
-		r.z = v[2];
+		r.x = v[0].get<float>();
+		r.y = v[1].get<float>();
+		r.z = v[2].get<float>();
 	}
 	catch (const std::exception &e) {
 		ASSERT(false, "%s: Bad list of %s; exception: %s", mFilename.toUtf8().c_str(), name.toUtf8().c_str(), e.what());
@@ -265,9 +279,9 @@ Vector3i WzConfig::vector3i(const WzString &name)
 	auto v = it.value();
 	ASSERT(v.size() == 3, "%s: Bad list of %s", mFilename.toUtf8().c_str(), name.toUtf8().c_str());
 	try {
-		r.x = v[0];
-		r.y = v[1];
-		r.z = v[2];
+		r.x = v[0].get<int>();
+		r.y = v[1].get<int>();
+		r.z = v[2].get<int>();
 	}
 	catch (const std::exception &e) {
 		ASSERT(false, "%s: Bad list of %s; exception: %s", mFilename.toUtf8().c_str(), name.toUtf8().c_str(), e.what());
@@ -294,8 +308,8 @@ Vector2i WzConfig::vector2i(const WzString &name)
 	auto v = it.value();
 	ASSERT(v.size() == 2, "Bad list of %s", name.toUtf8().c_str());
 	try {
-		r.x = v[0];
-		r.y = v[1];
+		r.x = v[0].get<int>();
+		r.y = v[1].get<int>();
 	}
 	catch (const std::exception &e) {
 		ASSERT(false, "%s: Bad list of %s; exception: %s", mFilename.toUtf8().c_str(), name.toUtf8().c_str(), e.what());
@@ -406,6 +420,10 @@ void WzConfig::beginArray(const WzString &name)
 		}
 		ASSERT(it.value().is_array(), "%s: beginArray() on non-array key \"%s\"", mFilename.toUtf8().c_str(), name.toUtf8().c_str());
 		mArray = it.value();
+		if (mArray.size() == 0)
+		{
+			return;
+		}
 		ASSERT(mArray.front().is_object(), "%s: beginArray() on non-object array \"%s\"", mFilename.toUtf8().c_str(), name.toUtf8().c_str());
 		pCurrentObj = &mArray.front();
 	}
@@ -441,7 +459,7 @@ void WzConfig::nextArrayItem()
 	}
 }
 
-int WzConfig::remainingArrayItems()
+size_t WzConfig::remainingArrayItems()
 {
 	return mArray.size();
 }
@@ -482,6 +500,12 @@ void WzConfig::endArray()
 	mArray = nlohmann::json::array();
 }
 
+void WzConfig::setValue(const WzString &key, const nlohmann::json &&value)
+{
+	ASSERT(pCurrentObj != nullptr, "pCurrentObj is null");
+	(*pCurrentObj)[key.toUtf8()] = value;
+}
+
 void WzConfig::setValue(const WzString &key, const nlohmann::json &value)
 {
 	ASSERT(pCurrentObj != nullptr, "pCurrentObj is null");
