@@ -568,11 +568,6 @@
 #  include <windows.h>
 
 #  if defined(WZ_CC_MSVC)
-//   notify people we are disabling these warning messages.
-#    pragma message (" *** Warnings 4018,4127,4389 have been squelched. ***")
-#    pragma warning (disable : 4018) // Shut up: '>' : signed/unsigned mismatch
-#    pragma warning (disable : 4127) // Shut up: conditional expression is constant (eg. "while(0)")
-#    pragma warning (disable : 4389) // Shut up: '==' : signed/unsigned mismatch
 
 #    define strcasecmp _stricmp
 #    define strncasecmp _strnicmp
@@ -618,7 +613,7 @@
 #endif
 
 
-#if !defined(WZ_C99) && !defined(va_copy)
+#if !defined(WZ_C99) && !defined(va_copy) && (!defined(_MSC_VER) || (_MSC_VER < 1900))
 /**
  * Implements the interface of the C99 macro va_copy such that we can use it on
  * non-C99 systems as well.
