@@ -75,52 +75,60 @@ GFX::GFX(GFXTYPE type, int coordsPerVertex) : mType(type), mCoordsPerVertex(coor
 {
 }
 
-void GFX::loadTexture(const char *filename, int maxWidth /*= -1*/, int maxHeight /*= -1*/)
+void GFX::loadTexture(const char *filename, gfx_api::texture_type textureType, int maxWidth /*= -1*/, int maxHeight /*= -1*/)
 {
 	ASSERT(mType == GFX_TEXTURE, "Wrong GFX type");
 	const char *extension = strrchr(filename, '.'); // determine the filetype
-	iV_Image image;
-	if (!extension || strcmp(extension, ".png") != 0)
+	if (!extension || (strcmp(extension, ".png") != 0
+#if defined(BASIS_ENABLED)
+		&& strcmp(extension, ".ktx2") != 0
+#endif
+		))
 	{
 		debug(LOG_ERROR, "Bad image filename: %s", filename);
 		return;
 	}
-	if (iV_loadImage_PNG(filename, &image))
-	{
-		scaleImageMaxSize(&image, maxWidth, maxHeight);
-		makeTexture(image.width, image.height, iV_getPixelFormat(&image), image.bmp);
-		iV_unloadImage(&image);
-	}
+	if (mTexture)
+		delete mTexture;
+	mTexture = gfx_api::context::get().loadTextureFromFile(filename, textureType, maxWidth, maxHeight);
 }
 
-void GFX::makeTexture(size_t width, size_t height, const gfx_api::pixel_format& format, const void *image)
+void GFX::loadTexture(iV_Image&& bitmap, gfx_api::texture_type textureType, const std::string& filename, int maxWidth /*= -1*/, int maxHeight /*= -1*/)
+{
+	ASSERT(mType == GFX_TEXTURE, "Wrong GFX type");
+	if (mTexture)
+		delete mTexture;
+	mTexture = gfx_api::context::get().loadTextureFromUncompressedImage(std::move(bitmap), textureType, filename, maxWidth, maxHeight);
+}
+
+void GFX::makeTexture(size_t width, size_t height, const gfx_api::pixel_format& format, const std::string& debugName)
 {
 	ASSERT(mType == GFX_TEXTURE, "Wrong GFX type");
 	if (mTexture)
 		delete mTexture;
 	if (width > 0 && height > 0)
 	{
-		mTexture = gfx_api::context::get().create_texture(1, width, height, format);
-		if (image != nullptr)
-			mTexture->upload(0u, 0u, 0u, width, height, format, image);
+		mTexture = gfx_api::context::get().create_texture(1, width, height, format, debugName);
 	}
-	mWidth = width;
-	mHeight = height;
-	mFormat = format;
 }
 
-void GFX::updateTexture(const void *image, size_t width, size_t height)
+void GFX::makeCompatibleTexture(const iV_Image* image /*= nullptr*/, const std::string& filename)
 {
 	ASSERT(mType == GFX_TEXTURE, "Wrong GFX type");
-	if (width == 0)
+	if (mTexture)
+		delete mTexture;
+	if (!image)
 	{
-		width = mWidth;
+		return;
 	}
-	if (height == 0)
-	{
-		height = mHeight;
-	}
-	mTexture->upload(0u, 0u, 0u, width, height, mFormat, image);
+	mTexture = gfx_api::context::get().createTextureForCompatibleImageUploads(1, *image, filename);
+}
+
+void GFX::updateTexture(const iV_Image& image /*= nullptr*/)
+{
+	ASSERT(mType == GFX_TEXTURE, "Wrong GFX type");
+	ASSERT_OR_RETURN(, mTexture != nullptr, "Null texture??");
+	mTexture->upload(0u, image);
 }
 
 void GFX::buffers(int vertices, const void *vertBuf, const void *auxBuf)
@@ -374,7 +382,7 @@ void iV_DrawImageTextClipped(gfx_api::texture& TextureID, Vector2i textureSize,
 template<typename PSO>
 static inline void pie_DrawImageTemplate(IMAGEFILE *imageFile, int id, Vector2i size, const PIERECT *dest, PIELIGHT colour, const glm::mat4 &modelViewProjection, Vector2i textureInset = Vector2i(0, 0))
 {
-	ImageDef const &image2 = imageFile->imageDefs[id];
+	AtlasImageDef const &image2 = imageFile->imageDefs[id];
 	size_t texPage = imageFile->pages[image2.TPageID].id;
 	gfx_api::gfxFloat invTextureSize = 1.f / (float)imageFile->pages[image2.TPageID].size;
 	float tu = (float)(image2.Tu + textureInset.x) * invTextureSize;
@@ -405,7 +413,7 @@ static void pie_DrawMultipleImages(const std::list<PieDrawImageRequest>& request
 		// pie_DrawImage(request.imageFile, request.ID, request.size, &request.dest, request.colour, request.modelViewProjection, request.textureInset)
 		// but is tweaked to use custom implementation of iv_DrawImageImpl that does not disable the shader after every glDrawArrays call.
 
-		ImageDef const &image2 = request.imageFile->imageDefs[request.ID];
+		AtlasImageDef const &image2 = request.imageFile->imageDefs[request.ID];
 		size_t texPage = request.imageFile->pages[image2.TPageID].id;
 		gfx_api::gfxFloat invTextureSize = 1.f / (float)request.imageFile->pages[image2.TPageID].size;
 		float tu = (float)(image2.Tu + request.textureInset.x) * invTextureSize;
@@ -442,7 +450,7 @@ static void pie_DrawMultipleImages(const std::list<PieDrawImageRequest>& request
 
 static Vector2i makePieImage(IMAGEFILE *imageFile, unsigned id, PIERECT *dest, int x, int y)
 {
-	ImageDef const &image = imageFile->imageDefs[id];
+	AtlasImageDef const &image = imageFile->imageDefs[id];
 	Vector2i pieImage;
 	pieImage.x = image.Width;
 	pieImage.y = image.Height;
@@ -459,12 +467,12 @@ static Vector2i makePieImage(IMAGEFILE *imageFile, unsigned id, PIERECT *dest, i
 void iV_DrawImage2(const WzString &filename, float x, float y, float width, float height)
 {
 	if (filename.isEmpty()) { return; }
-	ImageDef *image = iV_GetImage(filename);
+	AtlasImageDef *image = iV_GetImage(filename);
 	ASSERT_OR_RETURN(, image != nullptr, "No image found for filename: %s", filename.toUtf8().c_str());
 	iV_DrawImage2(image, x, y, width, height);
 }
 
-void iV_DrawImage2(const ImageDef *image, float x, float y, float width, float height)
+void iV_DrawImage2(const AtlasImageDef *image, float x, float y, float width, float height)
 {
 	ASSERT_NOT_NULLPTR_OR_RETURN(, image);
 	const gfx_api::gfxFloat invTextureSize = image->invTextureSize;
@@ -520,7 +528,7 @@ void iV_DrawImageFileAnisotropic(IMAGEFILE *ImageFile, UWORD ID, int x, int y, V
 	pie_DrawImageTemplate<gfx_api::DrawImageAnisotropicPSO>(ImageFile, ID, pieImage, &dest, pal_RGBA(255, 255, 255, alpha), modelViewProjection);
 }
 
-void iV_DrawImageTc(Image image, Image imageTc, int x, int y, PIELIGHT colour, const glm::mat4 &modelViewProjection)
+void iV_DrawImageTc(AtlasImage image, AtlasImage imageTc, int x, int y, PIELIGHT colour, const glm::mat4 &modelViewProjection)
 {
 	if (!assertValidImage(image.images, image.id) || !assertValidImage(imageTc.images, imageTc.id))
 	{
@@ -548,7 +556,7 @@ void iV_DrawImageRepeatX(IMAGEFILE *ImageFile, UWORD ID, int x, int y, int Width
 	}
 
 	assertValidImage(ImageFile, ID);
-	const ImageDef *Image = &ImageFile->imageDefs[ID];
+	const AtlasImageDef *Image = &ImageFile->imageDefs[ID];
 
 	REND_MODE mode = REND_OPAQUE;
 
@@ -596,7 +604,7 @@ void iV_DrawImageRepeatY(IMAGEFILE *ImageFile, UWORD ID, int x, int y, int Heigh
 	}
 
 	assertValidImage(ImageFile, ID);
-	const ImageDef *Image = &ImageFile->imageDefs[ID];
+	const AtlasImageDef *Image = &ImageFile->imageDefs[ID];
 
 	REND_MODE mode = REND_OPAQUE;
 
@@ -649,7 +657,11 @@ void pie_SetRadar(gfx_api::gfxFloat x, gfx_api::gfxFloat y, gfx_api::gfxFloat wi
 {
 	for (size_t i = 0; i < NUM_RADAR_TEXTURES; ++i)
 	{
-		radarGfx[i]->makeTexture(twidth, theight);
+		if (radarGfx[i] == nullptr)
+		{
+			continue;
+		}
+		radarGfx[i]->makeTexture(twidth, theight, gfx_api::pixel_format::FORMAT_RGBA8_UNORM_PACK8, std::string("mem::radarTexture[") + std::to_string(i) + "]");
 		//	glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);  // Want GL_LINEAR (or GL_LINEAR_MIPMAP_NEAREST) for min filter, but GL_NEAREST for mag filter. // TODO: Add a gfx_api::sampler_type to handle this case? bilinear, but nearest for mag?
 		gfx_api::gfxFloat texcoords[] = { 0.0f, 0.0f,  1.0f, 0.0f,  0.0f, 1.0f,  1.0f, 1.0f };
 		gfx_api::gfxFloat vertices[] = { x, y,  x + width, y,  x, y + height,  x + width, y + height };
@@ -658,14 +670,14 @@ void pie_SetRadar(gfx_api::gfxFloat x, gfx_api::gfxFloat y, gfx_api::gfxFloat wi
 }
 
 /** Store radar texture with given width and height. */
-void pie_DownLoadRadar(UDWORD *buffer)
+void pie_DownLoadRadar(const iV_Image& bitmap)
 {
 	currRadarGfx++;
 	if (currRadarGfx >= NUM_RADAR_TEXTURES)
 	{
 		currRadarGfx = 0;
 	}
-	radarGfx[currRadarGfx]->updateTexture(buffer);
+	radarGfx[currRadarGfx]->updateTexture(bitmap);
 }
 
 /** Display radar texture using the given height and width, depending on zoom level. */
