@@ -56,6 +56,7 @@ struct iTexPage
 {
 	std::string name;
 	gfx_api::texture* id = nullptr;
+	gfx_api::texture_type textureType = gfx_api::texture_type::user_interface;
 
 	iTexPage() = default;
 
@@ -64,6 +65,7 @@ struct iTexPage
 		std::swap(name, input.name);
 		id = input.id;
 		input.id = nullptr;
+		std::swap(textureType, input.textureType);
 	}
 
 	~iTexPage()
@@ -109,59 +111,43 @@ void pie_AssignTexture(size_t page, gfx_api::texture* texture)
 	_TEX_PAGE[page].id = texture;
 }
 
-static size_t pie_AddTexPage_Impl(iV_Image *s, const char *filename, bool gameTexture, size_t page)
+static size_t pie_AddTexPage_Impl(gfx_api::texture *pTexture, const char *filename, gfx_api::texture_type textureType, size_t page)
 {
-	ASSERT(s && filename, "Bad input parameter");
+	ASSERT(pTexture && filename, "Bad input parameter");
 
 	_NAME_TO_TEX_PAGE_MAP[filename] = page;
 	debug(LOG_TEXTURE, "%s page=%zu", filename, page);
 
-	if (gameTexture) // this is a game texture, use texture compression
-	{
-		gfx_api::pixel_format format = iV_getPixelFormat(s);
-		if (_TEX_PAGE[page].id)
-			delete _TEX_PAGE[page].id;
-		size_t mip_count = static_cast<size_t>(floor(log(std::max(s->width, s->height)))) + 1;
-		_TEX_PAGE[page].id = gfx_api::context::get().create_texture(mip_count, s->width, s->height, format, filename);
-		pie_Texture(page).upload_and_generate_mipmaps(0u, 0u, s->width, s->height, iV_getPixelFormat(s), s->bmp);
-	}
-	else	// this is an interface texture, do not use compression
-	{
-		if (_TEX_PAGE[page].id)
-			delete _TEX_PAGE[page].id;
-		_TEX_PAGE[page].id = gfx_api::context::get().create_texture(1, s->width, s->height, gfx_api::pixel_format::FORMAT_RGBA8_UNORM_PACK8, filename);
-		pie_Texture(page).upload(0u, 0u, 0u, s->width, s->height, iV_getPixelFormat(s), s->bmp);
-	}
-
-	// it is uploaded, we do not need it anymore
-	free(s->bmp);
-	s->bmp = nullptr;
+	if (_TEX_PAGE[page].id)
+		delete _TEX_PAGE[page].id;
+	_TEX_PAGE[page].id = pTexture;
+	_TEX_PAGE[page].textureType = textureType;
 
 	/* Send back the texpage number so we can store it in the IMD */
 	return page;
 }
 
-size_t pie_AddTexPage(iV_Image *s, const char *filename, bool gameTexture)
+size_t pie_AddTexPage(gfx_api::texture *pTexture, const char *filename, gfx_api::texture_type textureType)
 {
-	ASSERT(s && filename, "Bad input parameter");
+	ASSERT_OR_RETURN(0, pTexture && filename, "Bad input parameter");
 	ASSERT(_NAME_TO_TEX_PAGE_MAP.count(filename) == 0, "tex page %s already exists", filename);
 	iTexPage tex;
 	size_t page = _TEX_PAGE.size();
 	tex.name = filename;
 	_TEX_PAGE.push_back(std::move(tex));
 
-	return pie_AddTexPage_Impl(s, filename, gameTexture, page);
+	return pie_AddTexPage_Impl(pTexture, filename, textureType, page);
 }
 
-size_t pie_AddTexPage(iV_Image *s, const char *filename, bool gameTexture, size_t page)
+size_t pie_AddTexPage(gfx_api::texture *pTexture, const char *filename, gfx_api::texture_type textureType, size_t page)
 {
-	ASSERT(s && filename, "Bad input parameter");
+	ASSERT_OR_RETURN(0, pTexture && filename, "Bad input parameter");
 
 	// replace
 	_NAME_TO_TEX_PAGE_MAP.erase(_TEX_PAGE[page].name);
 	_TEX_PAGE[page].name = filename;
 
-	return pie_AddTexPage_Impl(s, filename, gameTexture, page);
+	return pie_AddTexPage_Impl(pTexture, filename, textureType, page);
 }
 
 /*!
@@ -201,40 +187,6 @@ std::string pie_MakeTexPageTCMaskName(const std::string& filename)
 	return result;
 }
 
-bool scaleImageMaxSize(iV_Image *s, int maxWidth, int maxHeight)
-{
-	if ((maxWidth <= 0 || s->width <= maxWidth) && (maxHeight <= 0 || s->height <= maxHeight))
-	{
-		return false;
-	}
-
-	double scalingRatio;
-	double widthRatio = (double)maxWidth / (double)s->width;
-	double heightRatio = (double)maxHeight / (double)s->height;
-	if (maxWidth > 0 && maxHeight > 0)
-	{
-		scalingRatio = std::min<double>(widthRatio, heightRatio);
-	}
-	else
-	{
-		scalingRatio = (maxWidth > 0) ? widthRatio : heightRatio;
-	}
-
-	int output_w = static_cast<int>(s->width * scalingRatio);
-	int output_h = static_cast<int>(s->height * scalingRatio);
-
-	unsigned char *output_pixels = (unsigned char *)malloc(static_cast<size_t>(output_w) * static_cast<size_t>(output_h) * s->depth);
-	stbir_resize_uint8(s->bmp, s->width, s->height, 0,
-					   output_pixels, output_w, output_h, 0,
-					   s->depth);
-	free(s->bmp);
-	s->width = output_w;
-	s->height = output_h;
-	s->bmp = output_pixels;
-
-	return true;
-}
-
 /** Retrieve the texture number for a given texture resource.
  *
  *  @note We keep textures in a separate data structure _TEX_PAGE apart from the
@@ -248,10 +200,9 @@ bool scaleImageMaxSize(iV_Image *s, int maxWidth, int maxHeight)
  *  @return a non-negative index number for the texture, negative if no texture
  *          with the given filename could be found
  */
-optional<size_t> iV_GetTransformTexture(const char *filename, std::function<void (iV_Image&)> transformImageData, bool compression, int maxWidth /*= -1*/, int maxHeight /*= -1*/)
+optional<size_t> iV_GetTexture(const char *filename, gfx_api::texture_type textureType, int maxWidth /*= -1*/, int maxHeight /*= -1*/)
 {
 	ASSERT(filename != nullptr, "filename must not be null");
-	iV_Image sSprite;
 
 	/* Have we already loaded this one then? */
 	std::string path = pie_MakeTexPageName(filename);
@@ -264,35 +215,21 @@ optional<size_t> iV_GetTransformTexture(const char *filename, std::function<void
 	// Try to load it
 	std::string loadPath = "texpages/";
 	loadPath += filename;
-	if (!iV_loadImage_PNG(loadPath.c_str(), &sSprite))
+	gfx_api::texture *pTexture = gfx_api::context::get().loadTextureFromFile(loadPath.c_str(), textureType, maxWidth, maxHeight);
+	if (!pTexture)
 	{
 		debug(LOG_ERROR, "Failed to load %s", loadPath.c_str());
 		return nullopt;
 	}
-	scaleImageMaxSize(&sSprite, maxWidth, maxHeight);
-	if (transformImageData)
-	{
-		transformImageData(sSprite);
-	}
-	size_t page = pie_AddTexPage(&sSprite, path.c_str(), compression);
+
+	size_t page = pie_AddTexPage(pTexture, path.c_str(), textureType);
 	resDoResLoadCallback(); // ensure loading screen doesn't freeze when loading large images
 	return optional<size_t>(page);
 }
 
-optional<size_t> iV_GetTexture(const char *filename, bool compression, int maxWidth /*= -1*/, int maxHeight /*= -1*/)
-{
-	return iV_GetTransformTexture(filename, nullptr, compression, maxWidth, maxHeight);
-}
-
 bool replaceTexture(const WzString &oldfile, const WzString &newfile)
 {
 	// Load new one to replace it
-	iV_Image image;
-	if (!iV_loadImage_PNG(WzString("texpages/" + newfile).toUtf8().c_str(), &image))
-	{
-		debug(LOG_ERROR, "Failed to load image: %s", newfile.toUtf8().c_str());
-		return false;
-	}
 	std::string tmpname = pie_MakeTexPageName(oldfile.toUtf8());
 	// Have we already loaded this one?
 	const auto it = _NAME_TO_TEX_PAGE_MAP.find(tmpname);
@@ -300,13 +237,13 @@ bool replaceTexture(const WzString &oldfile, const WzString &newfile)
 	{
 		gfx_api::context::get().debugStringMarker("Replacing texture");
 		size_t page = it->second;
+		gfx_api::texture_type existingTextureType = _TEX_PAGE[page].textureType;
 		debug(LOG_TEXTURE, "Replacing texture %s with %s from index %zu (tex id %u)", it->first.c_str(), newfile.toUtf8().c_str(), page, _TEX_PAGE[page].id->id());
+		gfx_api::texture *pTexture = gfx_api::context::get().loadTextureFromFile(WzString("texpages/" + newfile).toUtf8().c_str(), existingTextureType);
 		tmpname = pie_MakeTexPageName(newfile.toUtf8());
-		pie_AddTexPage(&image, tmpname.c_str(), true, page);
-		iV_unloadImage(&image);
+		pie_AddTexPage(pTexture, tmpname.c_str(), existingTextureType, page);
 		return true;
 	}
-	iV_unloadImage(&image);
 	debug(LOG_ERROR, "Nothing to replace!");
 	return false;
 }
@@ -328,11 +265,7 @@ void iV_unloadImage(iV_Image *image)
 {
 	if (image)
 	{
-		if (image->bmp)
-		{
-			free(image->bmp);
-			image->bmp = nullptr;
-		}
+		image->clear();
 	}
 	else
 	{
@@ -342,16 +275,18 @@ void iV_unloadImage(iV_Image *image)
 
 gfx_api::pixel_format iV_getPixelFormat(const iV_Image *image)
 {
-	switch (image->depth)
+	switch (image->channels())
 	{
 	case 1:
 		return gfx_api::pixel_format::FORMAT_R8_UNORM;
+	case 2:
+		return gfx_api::pixel_format::FORMAT_RG8_UNORM;
 	case 3:
 		return gfx_api::pixel_format::FORMAT_RGB8_UNORM_PACK8;
 	case 4:
 		return gfx_api::pixel_format::FORMAT_RGBA8_UNORM_PACK8;
 	default:
-		debug(LOG_FATAL, "iV_getPixelFormat: Unsupported image depth: %u", image->depth);
+		debug(LOG_FATAL, "iV_getPixelFormat: Unsupported image channels: %u", image->channels());
 		return gfx_api::pixel_format::invalid;
 	}
 }
