@@ -249,6 +249,7 @@ public:
 
 enum class AIDifficulty : int8_t
 {
+	SUPEREASY,
 	EASY,
 	MEDIUM,
 	HARD,
@@ -272,7 +273,7 @@ enum class NET_LOBBY_OPT_FIELD
 // currently controlled player.
 struct PLAYER
 {
-	char                name[StringSize];   ///< Player name
+	char                name[StringSize] = {};   ///< Player name
 	int32_t             position;           ///< Map starting position
 	int32_t             colour;             ///< Which colour slot this player is using
 	bool                allocated;          ///< Allocated as a human player
@@ -345,16 +346,16 @@ struct NETPLAY
 
 struct PLAYER_IP
 {
-	char	pname[40];
-	char	IPAddress[40];
+	char	pname[40] = {};
+	char	IPAddress[40] = {};
 };
-#define MAX_BANS 255
+#define MAX_BANS 1024
 // ////////////////////////////////////////////////////////////////////////
 // variables
 
 extern NETPLAY NetPlay;
 extern SYNC_COUNTER sync_counter;
-extern PLAYER_IP	*IPlist;
+std::vector<PLAYER_IP> NETgetIPBanList();
 // update flags
 extern bool netPlayersUpdated;
 extern char iptoconnect[PATH_MAX]; // holds IP/hostname from command line
@@ -546,6 +547,18 @@ struct PlayerReference
 		return index == NetPlay.hostPlayer;
 	}
 
+	bool isDetached() const
+	{
+		return detached != nullptr;
+	}
+
+	// Generally prefer to use the -> operator!
+	// (This is only safe if isDetached() == false !!)
+	uint32_t originalIndex() const
+	{
+		return index;
+	}
+
 private:
 	std::unique_ptr<PLAYER> detached = nullptr;
 	uint32_t index;
