@@ -185,6 +185,12 @@ public:
 		debug(LOG_ACTIVITY, "- loadedModsChanged: %s", modListToStr(loadedModHashes).c_str());
 	}
 
+	// game exit
+	virtual void gameExiting() override
+	{
+		debug(LOG_ACTIVITY, "- game exiting");
+	}
+
 private:
 	std::string modListToStr(const std::vector<Sha256>& modHashes) const
 	{
@@ -332,12 +338,18 @@ private:
 ActivityManager::ActivityManager()
 {
 	ASSERT_OR_RETURN(, PHYSFS_isInit() != 0, "PHYSFS must be initialized before the ActivityManager is created");
+}
+
+void ActivityManager::_initializeDB()
+{
+	ASSERT_OR_RETURN(, activityDatabase == nullptr, "DB already initialized?");
+	ASSERT_OR_RETURN(, PHYSFS_isInit() != 0, "PHYSFS must be initialized before the ActivityManager is created");
 	// init ActivityDatabase
 	const char *pWriteDir = PHYSFS_getWriteDir();
 	ASSERT(pWriteDir != nullptr, "PHYSFS_getWriteDir returned null");
 	if (pWriteDir)
 	{
-		std::string statsDBPath = std::string(pWriteDir) + PHYSFS_getDirSeparator() + "stats.db";
+		std::string statsDBPath = std::string(pWriteDir) + "/" + "stats.db";
 		try {
 			activityDatabase = std::make_shared<ActivityDatabase>(statsDBPath);
 		}
@@ -356,6 +368,7 @@ ActivityManager& ActivityManager::instance()
 
 bool ActivityManager::initialize()
 {
+	_initializeDB();
 	addActivitySink(std::make_shared<LoggingActivitySink>());
 	return true;
 }
@@ -376,7 +389,7 @@ void ActivityManager::addActivitySink(std::shared_ptr<ActivitySink> sink)
 
 void ActivityManager::removeActivitySink(const std::shared_ptr<ActivitySink>& sink)
 {
-	activitySinks.erase(std::remove(activitySinks.begin(), activitySinks.end(), sink));
+	activitySinks.erase(std::remove(activitySinks.begin(), activitySinks.end(), sink), activitySinks.end());
 }
 
 ActivitySink::GameMode ActivityManager::getCurrentGameMode() const
@@ -518,6 +531,8 @@ void ActivityManager::preSystemShutdown()
 		// quitGame was never generated - synthesize it
 		ActivityManager::instance().quitGame(collectEndGameStatsData(), Cheated);
 	}
+
+	for (auto sink : activitySinks) { sink->gameExiting(); }
 }
 
 void ActivityManager::navigateToMenu(const std::string& menuName)
@@ -768,6 +783,7 @@ void ActivityManager::updateMultiplayGameData(const MULTIPLAYERGAME& multiGame,
 	currentMultiplayGameInfo.currentPlayerIdx = selectedPlayer;
 	currentMultiplayGameInfo.players = NetPlay.players;
 	currentMultiplayGameInfo.players.resize(multiGame.maxPlayers);
+	currentMultiplayGameInfo.hostPlayer = NetPlay.hostPlayer;
 
 	currentMultiplayGameInfo.limit_no_tanks = (multiInGame.flags & MPFLAGS_NO_TANKS) != 0;
 	currentMultiplayGameInfo.limit_no_cyborgs = (multiInGame.flags & MPFLAGS_NO_CYBORGS) != 0;
@@ -782,7 +798,10 @@ void ActivityManager::updateMultiplayGameData(const MULTIPLAYERGAME& multiGame,
 
 	if (currentMode == ActivitySink::GameMode::JOINING_IN_PROGRESS || currentMode == ActivitySink::GameMode::JOINING_IN_LOBBY)
 	{
-		currentMultiplayGameInfo.hostName = currentMultiplayGameInfo.players[0].name; // host is always player index 0?
+		if (currentMultiplayGameInfo.hostPlayer < currentMultiplayGameInfo.players.size())
+		{
+			currentMultiplayGameInfo.hostName = currentMultiplayGameInfo.players[currentMultiplayGameInfo.hostPlayer].name;
+		}
 	}
 
 	if (currentMode == ActivitySink::GameMode::HOSTING_IN_LOBBY || currentMode == ActivitySink::GameMode::JOINING_IN_LOBBY)
