@@ -43,8 +43,8 @@ enum WT_CLASS
 
 void atmosInitSystem();
 void atmosUpdateSystem();
-void renderParticle(ATPART *psPart, const glm::mat4 &viewMatrix);
-void atmosDrawParticles(const glm::mat4 &viewMatrix);
+void renderParticle(ATPART *psPart, const glm::mat4 &perspectiveViewMatrix);
+void atmosDrawParticles(const glm::mat4 &viewMatrix, const glm::mat4 &perspectiveViewMatrix);
 void atmosSetWeatherType(WT_CLASS type);
 WT_CLASS atmosGetWeatherType();
 
