@@ -83,6 +83,7 @@ static bool wz_autogame = false;
 static std::string wz_saveandquit;
 static std::string wz_test;
 static std::string wz_autoratingUrl;
+static bool wz_autoratingEnable = false;
 static bool wz_cli_headless = false;
 static bool wz_streamer_spectator_mode = false;
 static bool wz_lobby_slashcommands = false;
@@ -277,7 +278,6 @@ static int poptGetNextOpt(poptContext ctx)
 		}
 	}
 	ctx->bad = match;
-	ctx->current++;
 	return POPT_ERROR_BADOPT;
 }
 
@@ -343,6 +343,7 @@ typedef enum
 #endif
 	CLI_GAMEPORT,
 	CLI_WZ_CRASH_RPT,
+	CLI_WZ_DEBUG_CRASH_HANDLER,
 	CLI_STREAMER_SPECTATOR,
 	CLI_LOBBY_SLASHCOMMANDS,
 	CLI_ADD_LOBBY_ADMINHASH,
@@ -351,6 +352,16 @@ typedef enum
 	CLI_STARTPLAYERS,
 } CLI_OPTIONS;
 
+// Separate table that avoids *any* translated strings, to avoid any risk of gettext / libintl function calls
+static const struct poptOption debugOptionsTable[] =
+{
+	{ "debug", POPT_ARG_STRING, CLI_DEBUG, nullptr, nullptr },
+	{ "debugfile", POPT_ARG_STRING, CLI_DEBUGFILE, nullptr, nullptr },
+	{ "flush-debug-stderr", POPT_ARG_NONE, CLI_FLUSHDEBUGSTDERR, nullptr, nullptr },
+	// Terminating entry
+	{ nullptr, 0, 0,              nullptr,                                    nullptr },
+};
+
 static const struct poptOption *getOptionsTable()
 {
 	static const struct poptOption optionsTable[] =
@@ -405,12 +416,13 @@ static const struct poptOption *getOptionsTable()
 		{ "skirmish", POPT_ARG_STRING, CLI_SKIRMISH,   N_("Start skirmish game with given settings file"), N_("test") },
 		{ "continue", POPT_ARG_NONE, CLI_CONTINUE,   N_("Continue the last saved game"), nullptr },
 		{ "autohost", POPT_ARG_STRING, CLI_AUTOHOST,   N_("Start host game with given settings file"), N_("autohost") },
-		{ "autorating", POPT_ARG_STRING, CLI_AUTORATING,   N_("Query ratings from given server url (containing \"{HASH}\"), when hosting"), N_("autorating") },
+		{ "autorating", POPT_ARG_STRING, CLI_AUTORATING,   N_("Query ratings from given server url, when hosting"), N_("autorating") },
 #if defined(WZ_OS_WIN)
 		{ "enableconsole", POPT_ARG_NONE, CLI_WIN_ENABLE_CONSOLE,   N_("Attach or create a console window and display console output (Windows only)"), nullptr },
 #endif
 		{ "gameport", POPT_ARG_STRING, CLI_GAMEPORT,   N_("Set game server port"), N_("port") },
 		{ "wz-crash-rpt", POPT_ARG_NONE, CLI_WZ_CRASH_RPT, nullptr, nullptr },
+		{ "wz-debug-crash-handler", POPT_ARG_NONE, CLI_WZ_DEBUG_CRASH_HANDLER, nullptr, nullptr },
 		{ "spectator-min-ui", POPT_ARG_NONE, CLI_STREAMER_SPECTATOR, nullptr, nullptr},
 		{ "enablelobbyslashcmd", POPT_ARG_NONE, CLI_LOBBY_SLASHCOMMANDS, N_("Enable lobby slash commands (for connecting clients)"), nullptr},
 		{ "addlobbyadminhash", POPT_ARG_STRING, CLI_ADD_LOBBY_ADMINHASH, N_("Add a lobby admin identity hash (for slash commands)"), _("hash string")},
@@ -451,18 +463,10 @@ static const struct poptOption *getOptionsTable()
 	return TranslatedOptionsTable;
 }
 
-//! Early parsing of the commandline
-/**
- * First half of the command line parsing. Also see ParseCommandLine()
- * below. The parameters here are needed early in the boot process,
- * while the ones in ParseCommandLine can benefit from debugging being
- * set up first.
- * \param argc number of arguments given
- * \param argv string array of the arguments
- * \return Returns true on success, false on error */
-bool ParseCommandLineEarly(int argc, const char * const *argv)
+// Must not trigger or call any gettext / libintl routines!
+bool ParseCommandLineDebugFlags(int argc, const char * const *argv)
 {
-	poptContext poptCon = poptGetContext(nullptr, argc, argv, getOptionsTable(), 0);
+	poptContext poptCon = poptGetContext(nullptr, argc, argv, debugOptionsTable, 0);
 	int iOption;
 
 #if defined(WZ_OS_MAC) && defined(DEBUG)
@@ -477,7 +481,7 @@ bool ParseCommandLineEarly(int argc, const char * const *argv)
 
 		if (iOption == POPT_ERROR_BADOPT)
 		{
-			qFatal("Unrecognized option: %s", poptBadOption(poptCon, 0));
+			continue;
 		}
 
 		switch (option)
@@ -516,6 +520,46 @@ bool ParseCommandLineEarly(int argc, const char * const *argv)
 			debugFlushStderr();
 			break;
 
+		default:
+			break;
+		};
+	}
+
+	return true;
+}
+
+//! Early parsing of the commandline
+/**
+ * First half of the command line parsing. Also see ParseCommandLine()
+ * below. The parameters here are needed early in the boot process,
+ * while the ones in ParseCommandLine can benefit from debugging being
+ * set up first.
+ * \param argc number of arguments given
+ * \param argv string array of the arguments
+ * \return Returns true on success, false on error */
+bool ParseCommandLineEarly(int argc, const char * const *argv)
+{
+	poptContext poptCon = poptGetContext(nullptr, argc, argv, getOptionsTable(), 0);
+	int iOption;
+
+#if defined(WZ_OS_MAC) && defined(DEBUG)
+	debug_enable_switch("all");
+#endif /* WZ_OS_MAC && DEBUG */
+
+	/* loop through command line */
+	while ((iOption = poptGetNextOpt(poptCon)) > 0 || iOption == POPT_ERROR_BADOPT)
+	{
+		CLI_OPTIONS option = (CLI_OPTIONS)iOption;
+		const char *token;
+
+		if (iOption == POPT_ERROR_BADOPT)
+		{
+			qFatal("Unrecognized option: %s", poptBadOption(poptCon, 0));
+		}
+
+		switch (option)
+		{
+
 		case CLI_CONFIGDIR:
 			// retrieve the configuration directory
 			token = poptGetOptArg(poptCon);
@@ -544,6 +588,7 @@ bool ParseCommandLineEarly(int argc, const char * const *argv)
 			break;
 #endif
 		case CLI_WZ_CRASH_RPT:
+		case CLI_WZ_DEBUG_CRASH_HANDLER:
 			// this is currently a no-op because it must be parsed even earlier than ParseCommandLineEarly
 			break;
 		default:
@@ -584,6 +629,7 @@ bool ParseCommandLine(int argc, const char * const *argv)
 		case CLI_WIN_ENABLE_CONSOLE:
 #endif
 		case CLI_WZ_CRASH_RPT:
+		case CLI_WZ_DEBUG_CRASH_HANDLER:
 			// These options are parsed in ParseCommandLineEarly() already, so ignore them
 			break;
 
@@ -781,6 +827,7 @@ bool ParseCommandLine(int argc, const char * const *argv)
 			{
 				qFatal("Unable to find specified replay");
 			}
+			setHostLaunch(HostLaunch::LoadReplay);
 			sstrcpy(sRequestResult, saveGameName); // hack to avoid crashes
 			SPinit(LEVEL_TYPE::SKIRMISH);
 			bMultiPlayer = true;
@@ -1007,16 +1054,6 @@ const std::string &wz_skirmish_test()
 	return wz_test;
 }
 
-std::string autoratingUrl(std::string const &hash) {
-	auto url = wz_autoratingUrl;
-	auto h = wz_autoratingUrl.find_first_of("{HASH}");
-	if (h != std::string::npos)
-	{
-		url.replace(h, 6, hash);
-	}
-	return url;
-}
-
 void setAutoratingUrl(std::string url) {
 	wz_autoratingUrl = url;
 }
@@ -1025,6 +1062,15 @@ std::string getAutoratingUrl() {
 	return wz_autoratingUrl;
 }
 
+void setAutoratingEnable(bool e)
+{
+	wz_autoratingEnable = e;
+}
+
+bool getAutoratingEnable() {
+	return wz_autoratingEnable;
+}
+
 bool streamer_spectator_mode()
 {
 	return wz_streamer_spectator_mode;
