@@ -320,7 +320,7 @@ void setReticuleFlash(int ButId, bool flash)
 // set up the button's size & hit-testing based on the dimensions of the "normal" image
 void setReticuleButtonDimensions(W_BUTTON &button, const WzString &filename)
 {
-	ImageDef *image = nullptr;
+	AtlasImageDef *image = nullptr;
 	if (!filename.isEmpty())
 	{
 		image = iV_GetImage(filename);
@@ -1322,7 +1322,7 @@ INT_RETVAL intRunWidgets()
 				char msg[256] = {'\0'};
 
 				sstrcpy(msg, _("GAME SAVED: "));
-				sstrcat(msg, saveGameName);
+				sstrcat(msg, savegameWithoutExtension(saveGameName));
 				addConsoleMessage(msg, LEFT_JUSTIFY, NOTIFY_MESSAGE);
 
 				if (widgGetFromID(psWScreen, IDMISSIONRES_SAVE))
@@ -1699,10 +1699,10 @@ INT_RETVAL intRunWidgets()
 					auto psBuilding = castStructureStats(psPositionStats);
 					if (psBuilding && selectedPlayer < MAX_PLAYERS)
 					{
-						STRUCTURE tmp(0, selectedPlayer);
 
 						if (psBuilding->type == REF_DEMOLISH)
 						{
+							STRUCTURE tmp(0, selectedPlayer);
 							MAPTILE *psTile = mapTile(map_coord(pos.x), map_coord(pos.y));
 							FEATURE *psFeature = (FEATURE *)psTile->psObject;
 							STRUCTURE *psStructure = (STRUCTURE *)psTile->psObject;
@@ -1719,8 +1719,8 @@ INT_RETVAL intRunWidgets()
 						}
 						else
 						{
+							STRUCTURE tmp(generateNewObjectId(), selectedPlayer);
 							STRUCTURE *psStructure = &tmp;
-							tmp.id = generateNewObjectId();
 							tmp.pStructureType = (STRUCTURE_STATS *)psPositionStats;
 							tmp.pos = {pos.x, pos.y, map_Height(pos.x, pos.y) + world_coord(1) / 10};
 
@@ -2160,11 +2160,11 @@ void makeObsoleteButton(const std::shared_ptr<WIDGET> &parent)
 	obsoleteButton->id = IDSTAT_OBSOLETE_BUTTON;
 	obsoleteButton->style |= WBUT_SECONDARY;
 	obsoleteButton->setChoice(includeRedundantDesigns);
-	obsoleteButton->setImages(false, MultipleChoiceButton::Images(Image(IntImages, IMAGE_OBSOLETE_HIDE_UP), Image(IntImages, IMAGE_OBSOLETE_HIDE_UP), Image(IntImages, IMAGE_OBSOLETE_HIDE_HI)));
+	obsoleteButton->setImages(false, MultipleChoiceButton::Images(AtlasImage(IntImages, IMAGE_OBSOLETE_HIDE_UP), AtlasImage(IntImages, IMAGE_OBSOLETE_HIDE_UP), AtlasImage(IntImages, IMAGE_OBSOLETE_HIDE_HI)));
 	obsoleteButton->setTip(false, _("Hiding Obsolete Tech"));
-	obsoleteButton->setImages(true,  MultipleChoiceButton::Images(Image(IntImages, IMAGE_OBSOLETE_SHOW_UP), Image(IntImages, IMAGE_OBSOLETE_SHOW_UP), Image(IntImages, IMAGE_OBSOLETE_SHOW_HI)));
+	obsoleteButton->setImages(true,  MultipleChoiceButton::Images(AtlasImage(IntImages, IMAGE_OBSOLETE_SHOW_UP), AtlasImage(IntImages, IMAGE_OBSOLETE_SHOW_UP), AtlasImage(IntImages, IMAGE_OBSOLETE_SHOW_HI)));
 	obsoleteButton->setTip(true, _("Showing Obsolete Tech"));
-	obsoleteButton->move(4 + Image(IntImages, IMAGE_FDP_UP).width() + 4, STAT_SLDY);
+	obsoleteButton->move(4 + AtlasImage(IntImages, IMAGE_FDP_UP).width() + 4, STAT_SLDY);
 }
 
 /* Add the stats widgets to the widget screen */
@@ -2286,8 +2286,8 @@ static bool intAddDebugStatsForm(BASE_STATS **_ppsStatsList, UDWORD numStats)
 			bar = widgAddBarGraph(psWScreen, &sBarInit);
 			bar->setBackgroundColour(WZCOL_BLACK);
 		}
-		WzString costString = WzString::fromUtf8(_("\nCost: %1"));
-		costString.replace("%1", WzString::number(powerCost));
+		WzString costString = WzString::fromUtf8(astringf(_("Cost: %u"), powerCost));
+		tipString.append("\n");
 		tipString.append(costString);
 		button->setTip(tipString.toUtf8().c_str());
 
@@ -2530,8 +2530,6 @@ bool intAddProximityButton(PROXIMITY_DISPLAY *psProxDisp, UDWORD inc)
 	W_FORMINIT sBFormInit;
 	sBFormInit.formID = 0;
 	sBFormInit.id = IDPROX_START + inc;
-	//store the ID so we can detect which one has been clicked on
-	psProxDisp->buttonID = sBFormInit.id;
 
 	// loop back and find a free one!
 	if (sBFormInit.id >= IDPROX_END)
@@ -2565,6 +2563,10 @@ bool intAddProximityButton(PROXIMITY_DISPLAY *psProxDisp, UDWORD inc)
 	{
 		return false;
 	}
+
+	//store the ID so we can detect which one has been clicked on
+	psProxDisp->buttonID = sBFormInit.id;
+
 	return true;
 }
 
