@@ -128,8 +128,8 @@ protected:
 
 	void initDisplay();
 	void displayClear(int xOffset, int yOffset);
-	void displayIMD(Image image, ImdObject imdObject, int xOffset, int yOffset);
-	void displayImage(Image image, int xOffset, int yOffset);
+	void displayIMD(AtlasImage image, ImdObject imdObject, int xOffset, int yOffset);
+	void displayImage(AtlasImage image, int xOffset, int yOffset);
 	void displayBlank(int xOffset, int yOffset);
 	void displayIfHighlight(int xOffset, int yOffset);
 
