@@ -473,7 +473,9 @@ enum INTFAC_TYPE
 	IMAGE_OBSERVE_DOWN,
 	// end: not currently used?
 	IMAGE_SPECSTATS_DOWN,
-	IMAGE_SPECSTATS_UP
+	IMAGE_SPECSTATS_UP,
+	IMAGE_INTFAC_VOLUME_UP,
+	IMAGE_INTFAC_VOLUME_MUTE
 };
 
 #endif //__INCLUDED_SRC_INTFAC_H__
