@@ -423,7 +423,7 @@ bool runInGameKeyMapEditor(InputManager& inputManager, const KeyFunctionConfigur
 		bAllowOtherKeyPresses = true;
 		if (id == KM_GO_BACK)
 		{
-			startIGOptionsMenu();
+			intReopenMenuWithoutUnPausing();
 			return false;
 		}
 		return true;
