@@ -42,8 +42,6 @@
 #include "warzoneconfig.h"
 
 // These magic values determine the fog
-#define FOG_BEGIN 4000
-#define FOG_END 8000
 #define FOG_ALTITUDE_COEFFICIENT 1.3f
 
 /*	The vector that holds the sun's lighting direction - planar */
@@ -306,9 +304,25 @@ static UDWORD calcDistToTile(UDWORD tileX, UDWORD tileY, Vector3i *pos)
 /// "popping" tiles
 void updateFogDistance(float distance)
 {
-	pie_UpdateFogDistance(FOG_BEGIN + (distance - war_GetMapZoom()) * FOG_ALTITUDE_COEFFICIENT, FOG_END + (distance - war_GetMapZoom()) * FOG_ALTITUDE_COEFFICIENT);
+	pie_UpdateFogDistance(war_getFogStart() + (distance - war_GetMapZoom()) * FOG_ALTITUDE_COEFFICIENT, war_getFogEnd() + (distance - war_GetMapZoom()) * FOG_ALTITUDE_COEFFICIENT);
 }
 
+void setDefaultFogColour()
+{
+	ASSERT(tilesetDir != nullptr, "Uninitialized tilesetDir");
+	if (tilesetDir && strcmp(tilesetDir, "texpages/tertilesc2hw") == 0) // Urban = 0x101040 (or, 0xc9920f)
+	{
+		pie_SetFogColour(WZCOL_FOG_URBAN);
+	}
+	else if (tilesetDir && strcmp(tilesetDir, "texpages/tertilesc3hw") == 0) // Rockies = 0xb6e1ec
+	{
+		pie_SetFogColour(WZCOL_FOG_ROCKIE);
+	}
+	else // Arizona, eg. strcmp(tilesetDir, "texpages/tertilesc1hw") == 0, and default. = b08f5f (or, 0x78684f)
+	{
+		pie_SetFogColour(WZCOL_FOG_ARIZONA);
+	}
+}
 
 #define MIN_DROID_LIGHT_LEVEL	96
 #define	DROID_SEEK_LIGHT_SPEED	2
