@@ -140,6 +140,8 @@ static GAMECODE renderLoop()
 		intAddInGamePopup();
 	}
 
+	bool skipDrawing = !gfx_api::context::get().shouldDraw();
+
 	audio_Update();
 
 	wzShowMouse(true);
@@ -250,7 +252,7 @@ static GAMECODE renderLoop()
 					if (saveGame(sRequestResult, GTYPE_SAVE_START))
 					{
 						sstrcpy(msgbuffer, _("GAME SAVED: "));
-						sstrcat(msgbuffer, sRequestResult);
+						sstrcat(msgbuffer, savegameWithoutExtension(sRequestResult));
 						addConsoleMessage(msgbuffer, LEFT_JUSTIFY, NOTIFY_MESSAGE);
 					}
 					else
@@ -266,7 +268,7 @@ static GAMECODE renderLoop()
 					if (saveGame(sRequestResult, GTYPE_SAVE_MIDMISSION))//mid mission from [esc] menu
 					{
 						sstrcpy(msgbuffer, _("GAME SAVED: "));
-						sstrcat(msgbuffer, sRequestResult);
+						sstrcat(msgbuffer, savegameWithoutExtension(sRequestResult));
 						addConsoleMessage(msgbuffer, LEFT_JUSTIFY, NOTIFY_MESSAGE);
 					}
 					else
@@ -298,7 +300,7 @@ static GAMECODE renderLoop()
 			pie_LoadBackDrop(SCREEN_RANDOMBDROP);
 		}
 	}
-	if (!loop_GetVideoStatus() && !quitting && !headlessGameMode())
+	if (!loop_GetVideoStatus() && !quitting && !headlessGameMode() && !skipDrawing)
 	{
 		if (!gameUpdatePaused())
 		{
@@ -372,18 +374,6 @@ static GAMECODE renderLoop()
 		break;
 	}
 
-	int clearMode = 0;
-	if (getDrawShadows())
-	{
-		clearMode |= CLEAR_SHADOW;
-	}
-	if (quitting || loopMissionState == LMS_SAVECONTINUE)
-	{
-		pie_SetFogStatus(false);
-		clearMode = CLEAR_BLACK;
-	}
-	pie_ScreenFlip(clearMode);//gameloopflip
-
 	if (quitting)
 	{
 		return GAMECODE_QUITGAME;
@@ -693,6 +683,7 @@ GAMECODE gameLoop()
 
 	unsigned before = wzGetTicks();
 	GAMECODE renderReturn = renderLoop();
+	pie_ScreenFrameRenderEnd(); // must happen here for proper renderBudget calculation
 	unsigned after = wzGetTicks();
 
 	renderBudget += (after - before) * updateFraction.n;
@@ -716,8 +707,7 @@ void videoLoop()
 	ASSERT(videoMode == 1, "videoMode out of sync");
 
 	// display a frame of the FMV
-	videoFinished = !seq_UpdateFullScreenVideo(nullptr);
-	pie_ScreenFlip(CLEAR_BLACK);
+	videoFinished = !seq_UpdateFullScreenVideo();
 
 	if (skipCounter <= SEQUENCE_MIN_SKIP_DELAY)
 	{
@@ -763,7 +753,6 @@ void loop_SetVideoPlaybackMode()
 	audio_StopAll();
 	wzShowMouse(false);
 	screen_StopBackDrop();
-	pie_ScreenFlip(CLEAR_BLACK);
 }
 
 
