@@ -34,17 +34,6 @@
 #include "display.h"
 #include "ai.h"
 
-#define ARIZONA 1
-#define URBAN 2
-#define ROCKIE 3
-
-enum MAP_TILESET_TYPE
-{
-	TILESET_ARIZONA = 0,
-	TILESET_URBAN = 1,
-	TILESET_ROCKIES = 2
-};
-
 #define TALLOBJECT_YMAX		(200)
 #define TALLOBJECT_ADJUST	(300)
 
@@ -255,10 +244,27 @@ static inline bool TileHasFeature(const MAPTILE *tile)
 /** Check if tile contains a wall structure. Function is NOT thread-safe. */
 static inline bool TileHasWall(const MAPTILE *tile)
 {
+	const auto *psStruct = (STRUCTURE *)tile->psObject;
 	return TileHasStructure(tile)
-	       && (((STRUCTURE *)tile->psObject)->pStructureType->type == REF_WALL
-	           || ((STRUCTURE *)tile->psObject)->pStructureType->type == REF_GATE
-	           || ((STRUCTURE *)tile->psObject)->pStructureType->type == REF_WALLCORNER);
+	       && (psStruct->pStructureType->type == REF_WALL
+	           || psStruct->pStructureType->type == REF_GATE
+	           || psStruct->pStructureType->type == REF_WALLCORNER);
+}
+
+/** Check if tile contains a wall structure. Function is NOT thread-safe.
+ * This function is specifically for raycast callback, because "TileHasWall" is used
+ * to decide wether or not it's possible to place a new defense structure on top of a wall.
+ * We do not want to allow place more defense structures on top of already existing ones.
+*/
+static inline bool TileHasWall_raycast(const MAPTILE *tile)
+{
+	const auto *psStruct = (STRUCTURE *)tile->psObject;
+	return TileHasStructure(tile)
+	       && (psStruct->pStructureType->type == REF_WALL
+	           || psStruct->pStructureType->type == REF_GATE
+	           // hadrcrete towers are technically a WALL + weapon, so count them as walls too
+	           || psStruct->pStructureType->combinesWithWall
+	           || psStruct->pStructureType->type == REF_WALLCORNER);
 }
 
 /** Check if tile is burning. */
@@ -314,7 +320,10 @@ static inline bool TEST_TILE_VISIBLE_TO_SELECTEDPLAYER(MAPTILE *pTile)
 		// always visible
 		return true;
 	}
-	ASSERT_OR_RETURN(false, selectedPlayer < MAX_PLAYERS, "Players should always have a selectedPlayer / player index < MAX_PLAYERS; non-players are always expected to have godMode enabled; selectedPlayer: %" PRIu32 "", selectedPlayer);
+	if (selectedPlayer >= MAX_PLAYERS)
+	{
+		return false;
+	}
 	return TEST_TILE_VISIBLE(selectedPlayer, pTile);
 }
 
@@ -380,10 +389,22 @@ bool mapLoadFromWzMapData(std::shared_ptr<WzMap::MapData> mapData);
 
 class WzMapPhysFSIO : public WzMap::IOProvider
 {
+public:
+	WzMapPhysFSIO() { }
+	WzMapPhysFSIO(const std::string& baseMountPath)
+	: m_basePath(baseMountPath)
+	{ }
 public:
 	virtual std::unique_ptr<WzMap::BinaryIOStream> openBinaryStream(const std::string& filename, WzMap::BinaryIOStream::OpenMode mode) override;
 	virtual bool loadFullFile(const std::string& filename, std::vector<char>& fileData) override;
 	virtual bool writeFullFile(const std::string& filename, const char *ppFileData, uint32_t fileSize) override;
+	virtual bool makeDirectory(const std::string& directoryPath) override;
+	virtual const char* pathSeparator() const override;
+
+	virtual bool enumerateFiles(const std::string& basePath, const std::function<bool (const char* file)>& enumFunc) override;
+	virtual bool enumerateFolders(const std::string& basePath, const std::function<bool (const char* file)>& enumFunc) override;
+private:
+	std::string m_basePath;
 };
 
 class WzMapDebugLogger : public WzMap::LoggingProtocol
@@ -546,6 +567,8 @@ WZ_DECL_ALWAYS_INLINE static inline bool hasSensorOnTile(MAPTILE *psTile, unsign
 void mapInit();
 void mapUpdate();
 
+bool loadTerrainTypeMapOverride(MAP_TILESET tileSet);
+
 //For saves to determine if loading the terrain type override should occur
 extern bool builtInMap;
 
