@@ -2427,7 +2427,7 @@ void intRunMissionResult()
 
 					saveGame(sRequestResult, GTYPE_SAVE_START);
 					sstrcpy(msg, _("GAME SAVED :"));
-					sstrcat(msg, sRequestResult);
+					sstrcat(msg, savegameWithoutExtension(sRequestResult));
 					addConsoleMessage(msg, LEFT_JUSTIFY, NOTIFY_MESSAGE);
 				}
 			}
@@ -3145,7 +3145,7 @@ std::string getCampaignName()
 	UDWORD campaignNum = getCampaignNumber();
 	std::string campaignName;
 	std::vector<CAMPAIGN_FILE> list = readCampaignFiles();
-	if (list.size() >= campaignNum)
+	if (campaignNum > 0 && campaignNum <= list.size())
 	{
 		campaignName = list[campaignNum - 1].name.toStdString();
 	}
