@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2019  Warzone 2100 Project
+	Copyright (C) 2005-2020  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -1050,17 +1050,26 @@ static void moveCalcDroidSlide(DROID *psDroid, int *pmx, int *pmy)
 		}
 		if (psObj->type == OBJ_DROID)
 		{
-			if (isTransporter((DROID *)psObj))
+			DROID * psObjcast = static_cast<DROID*> (psObj);
+			objR = moveObjRadius(psObj);
+			if (isTransporter(psObjcast))
 			{
 				// ignore transporters
 				continue;
 			}
-			if (!bLegs && ((DROID *)psObj)->droidType == DROID_PERSON)
+			if ((!isFlying(psDroid) && isFlying(psObjcast) && psObjcast->pos.z > (psDroid->pos.z + droidR)) || 
+			    (!isFlying(psObjcast) && isFlying(psDroid) && psDroid->pos.z > (psObjcast->pos.z + objR)))
+			{
+				// ground unit can't bump into a flying saucer..
+				continue;
+
+			}
+			if (!bLegs && (psObjcast)->droidType == DROID_PERSON)
 			{
 				// everything else doesn't avoid people
 				continue;
 			}
-			if (psObj->player == psDroid->player
+			if (psObjcast->player == psDroid->player
 			    && psDroid->lastFrustratedTime > 0
 			    && gameTime - psDroid->lastFrustratedTime < FRUSTRATED_TIME)
 			{
@@ -1306,7 +1315,7 @@ SDWORD moveCalcDroidSpeed(DROID *psDroid)
 	CHECK_DROID(psDroid);
 
 	// NOTE: This screws up since the transporter is offscreen still (on a mission!), and we are trying to find terrainType of a tile (that is offscreen!)
-	if (psDroid->droidType == DROID_TRANSPORTER && missionIsOffworld())
+	if (psDroid->droidType == DROID_SUPERTRANSPORTER && missionIsOffworld())
 	{
 		PROPULSION_STATS	*propulsion = asPropulsionStats + psDroid->asBits[COMP_PROPULSION];
 		speed = propulsion->maxSpeed;
@@ -1611,9 +1620,10 @@ static void moveUpdatePersonModel(DROID *psDroid, SDWORD speed, uint16_t directi
 	if (moveDroidStopped(psDroid, speed))
 	{
 		if (psDroid->droidType == DROID_PERSON &&
-		    (psDroid->action == DACTION_ATTACK ||
-		     psDroid->action == DACTION_ROTATETOATTACK)
-		    && psDroid->animationEvent == ANIM_EVENT_NONE)
+			(psDroid->action == DACTION_ATTACK ||
+			psDroid->action == DACTION_ROTATETOATTACK)
+			&& psDroid->animationEvent != ANIM_EVENT_DYING
+			&& psDroid->animationEvent != ANIM_EVENT_FIRING)
 		{
 			psDroid->timeAnimationStarted = gameTime;
 			psDroid->animationEvent = ANIM_EVENT_FIRING;
@@ -1647,8 +1657,8 @@ static void moveUpdatePersonModel(DROID *psDroid, SDWORD speed, uint16_t directi
 	//set the droid height here so other routines can use it
 	psDroid->pos.z = map_Height(psDroid->pos.x, psDroid->pos.y);//jps 21july96
 
-	/* update anim if moving and not shooting */
-	if (psDroid->droidType == DROID_PERSON && speed != 0 && psDroid->animationEvent == ANIM_EVENT_NONE)
+	/* update anim if moving */
+	if (psDroid->droidType == DROID_PERSON && speed != 0 && (psDroid->animationEvent != ANIM_EVENT_ACTIVE && psDroid->animationEvent != ANIM_EVENT_DYING))
 	{
 		psDroid->timeAnimationStarted = gameTime;
 		psDroid->animationEvent = ANIM_EVENT_ACTIVE;
@@ -1696,13 +1706,6 @@ static void moveAdjustVtolHeight(DROID *psDroid, int32_t iMapHeight)
 	}
 }
 
-// set a vtol to be hovering in the air
-void moveMakeVtolHover(DROID *psDroid)
-{
-	psDroid->sMove.Status = MOVEHOVER;
-	psDroid->pos.z = map_Height(psDroid->pos.x, psDroid->pos.y) + VTOL_HEIGHT_LEVEL;
-}
-
 static void moveUpdateVtolModel(DROID *psDroid, SDWORD speed, uint16_t direction)
 {
 	int fPerpSpeed, fNormalSpeed;
@@ -1831,7 +1834,7 @@ bool moveCheckDroidMovingAndVisible(void *psObj)
 	/* check for dead, not moving or invisible to player */
 	if (psDroid->died || moveDroidStopped(psDroid, 0) ||
 	    (isTransporter(psDroid) && psDroid->order.type == DORDER_NONE) ||
-	    !(psDroid->visible[selectedPlayer]))
+	    !(psDroid->visibleForLocalDisplay()))
 	{
 		psDroid->iAudioID = NO_SOUND;
 		return false;
@@ -1850,7 +1853,7 @@ static void movePlayDroidMoveAudio(DROID *psDroid)
 	ASSERT_OR_RETURN(, psDroid != nullptr, "Unit pointer invalid");
 
 	if ((psDroid != nullptr) &&
-	    (psDroid->visible[selectedPlayer]))
+	    (psDroid->visibleForLocalDisplay()))
 	{
 		PROPULSION_STATS *psPropStats = asPropulsionStats + psDroid->asBits[COMP_PROPULSION];
 		ASSERT_OR_RETURN(, psPropStats != nullptr, "Invalid propulsion stats pointer");
@@ -1961,7 +1964,7 @@ static void movePlayAudio(DROID *psDroid, bool bStarted, bool bStoppedBefore, SD
 	}
 
 	if ((iAudioID != NO_SOUND) &&
-	    (psDroid->visible[selectedPlayer]))
+	    (psDroid->visibleForLocalDisplay()))
 	{
 		if (audio_PlayObjDynamicTrack(psDroid, iAudioID,
 		                              pAudioCallback))
@@ -1974,11 +1977,26 @@ static void movePlayAudio(DROID *psDroid, bool bStarted, bool bStoppedBefore, SD
 
 static bool pickupOilDrum(int toPlayer, int fromPlayer)
 {
-	addPower(toPlayer, OILDRUM_POWER);  // give power
+	unsigned int power = OILDRUM_POWER;
+
+	if (!bMultiPlayer && !bInTutorial)
+	{
+		// Let Beta and Gamma campaign oil drums give a little more power
+		if (getCampaignNumber() == 2)
+		{
+			power = OILDRUM_POWER + (OILDRUM_POWER / 2);
+		}
+		else if (getCampaignNumber() == 3)
+		{
+			power = OILDRUM_POWER * 2;
+		}
+	}
+
+	addPower(toPlayer, power);  // give power
 
 	if (toPlayer == selectedPlayer)
 	{
-		CONPRINTF(_("You found %u power in an oil drum."), OILDRUM_POWER);
+		CONPRINTF(_("You found %u power in an oil drum."), power);
 	}
 
 	return true;
@@ -2303,7 +2321,7 @@ void moveUpdateDroid(DROID *psDroid)
 		objTrace(psDroid->id, "MOVETURNTOTARGET complete");
 	}
 
-	if (psDroid->periodicalDamageStart != 0 && psDroid->droidType != DROID_PERSON && psDroid->visible[selectedPlayer])
+	if (psDroid->periodicalDamageStart != 0 && psDroid->droidType != DROID_PERSON && psDroid->visibleForLocalDisplay()) // display-only check for adding effect
 	{
 		pos.x = psDroid->pos.x + (18 - rand() % 36);
 		pos.z = psDroid->pos.y + (18 - rand() % 36);
