@@ -234,7 +234,7 @@ void giftRadar(uint8_t from, uint8_t to, bool send)
 	else
 	{
 		hqReward(from, to);
-		if (to == selectedPlayer)
+		if (to == selectedPlayer && loopMissionState == LMS_NORMAL)
 		{
 			CONPRINTF(_("%s Gives You A Visibility Report"), getPlayerName(from));
 		}
@@ -726,8 +726,7 @@ void recvMultiPlayerFeature(NETQUEUE queue)
 		if (asFeatureStats[i].ref == ref)
 		{
 			// Create a feature of the specified type at the given location
-			FEATURE *result = buildFeature(&asFeatureStats[i], x, y, false);
-			result->id = id;
+			buildFeature(&asFeatureStats[i], x, y, false, id);
 			break;
 		}
 	}
@@ -788,6 +787,8 @@ void createTeamAlliances()
 		for (unsigned j = 0; j < MAX_PLAYERS; j++)
 		{
 			if (i != j														// two different players
+			    && i != scavengerSlot()										// ...not scavenger player
+			    && j != scavengerSlot()
 			    && NetPlay.players[i].team == NetPlay.players[j].team		// ...belonging to the same team
 			    && !aiCheckAlliances(i, j)									// ...not allied and not ignoring teams
 			    && NetPlay.players[i].difficulty != AIDifficulty::DISABLED
