@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2019  Warzone 2100 Project
+	Copyright (C) 2005-2020  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -24,9 +24,10 @@
 #ifndef __INCLUDED_MULTILIMIT_H__
 #define __INCLUDED_MULTILIMIT_H__
 
-bool startLimitScreen();
-void runLimitScreen();
-void applyLimitSet();
+// See titleui.h for the actual class; dependency reduction measure
+
+bool applyLimitSet();
 void createLimitSet();
+void resetLimits(void);
 
 #endif //__cplusplus //__INCLUDED_MULTILIMIT_H__
