@@ -29,10 +29,10 @@
 #include <chrono>
 
 #include "lib/framework/frame.h"
-#include "lib/ivis_opengl/piepalette.h" // for pal_Init()
 #include "lib/framework/input.h"
 #include "lib/framework/strres.h"
 #include "lib/framework/physfs_ext.h"
+#include "lib/ivis_opengl/piepalette.h" // for pal_Init()
 #include "map.h"
 
 #include "game.h"									// for loading maps
@@ -63,6 +63,7 @@
 #include "qtscript.h"
 #include "design.h"
 #include "advvis.h"
+#include "lighting.h" // for reInitPaletteAndFog()
 
 #include "template.h"
 #include "lib/netplay/netplay.h"								// the netplay library.
@@ -82,6 +83,7 @@
 #include "warzoneconfig.h"
 #include "stdinreader.h"
 #include "spectatorwidgets.h"
+#include "challenge.h"
 
 // ////////////////////////////////////////////////////////////////////////////
 // ////////////////////////////////////////////////////////////////////////////
@@ -95,7 +97,7 @@ MULTIPLAYERGAME				game;									//info to describe game.
 MULTIPLAYERINGAME			ingame;
 
 char						beaconReceiveMsg[MAX_PLAYERS][MAX_CONSOLE_STRING_LENGTH];	//beacon msg for each player
-char								playerName[MAX_PLAYERS][MAX_STR_LENGTH];	//Array to store all player names (humans and AIs)
+char						playerName[MAX_CONNECTED_PLAYERS][MAX_STR_LENGTH];	//Array to store all player names (humans and AIs)
 
 #define DATACHECK2_INTERVAL_MS 10000
 
@@ -454,16 +456,8 @@ DROID *IdToMissionDroid(UDWORD id, UDWORD player)
 	return nullptr;
 }
 
-// ////////////////////////////////////////////////////////////////////////////
-// find a structure
-STRUCTURE *IdToStruct(UDWORD id, UDWORD player)
+static STRUCTURE* _IdToStruct(UDWORD id, UDWORD beginPlayer, UDWORD endPlayer)
 {
-	int beginPlayer = 0, endPlayer = MAX_PLAYERS;
-	if (player != ANYPLAYER)
-	{
-		beginPlayer = player;
-		endPlayer = std::min<int>(player + 1, MAX_PLAYERS);
-	}
 	STRUCTURE **lists[2] = {apsStructLists, mission.apsStructLists};
 	for (int j = 0; j < 2; ++j)
 	{
@@ -480,6 +474,24 @@ STRUCTURE *IdToStruct(UDWORD id, UDWORD player)
 	}
 	return nullptr;
 }
+// ////////////////////////////////////////////////////////////////////////////
+// find a structure
+STRUCTURE *IdToStruct(UDWORD id, UDWORD player)
+{
+	int beginPlayer = 0, endPlayer = MAX_PLAYERS;
+	if (player != ANYPLAYER)
+	{
+		beginPlayer = player;
+		endPlayer = std::min<int>(player + 1, MAX_PLAYERS);
+	}
+	STRUCTURE *out = nullptr;
+	out = _IdToStruct(id, beginPlayer, endPlayer);
+	if (out)
+	{
+		return out;
+	}
+	return nullptr;
+}
 
 // ////////////////////////////////////////////////////////////////////////////
 // find a feature
@@ -556,22 +568,19 @@ BASE_OBJECT *IdToPointer(UDWORD id, UDWORD player)
 
 // ////////////////////////////////////////////////////////////////////////////
 // return a players name.
-const char *getPlayerName(int player)
+const char *getPlayerName(int player, bool storedName /*= false*/)
 {
 	ASSERT_OR_RETURN(nullptr, player >= 0, "Wrong player index: %d", player);
 
+	const bool aiPlayer = (static_cast<size_t>(player) < NetPlay.players.size()) && (NetPlay.players[player].ai >= 0) && !NetPlay.players[player].allocated;
+
 	// playerName is created through setPlayerName()
-	if (player < MAX_PLAYERS && strcmp(playerName[player], "") != 0)
+	if (storedName && !aiPlayer && player < MAX_CONNECTED_PLAYERS && strcmp(playerName[player], "") != 0)
 	{
 		return (char *)&playerName[player];
 	}
 
-	if (static_cast<size_t>(player) >= NetPlay.players.size() || strlen(NetPlay.players[player].name) == 0)
-	{
-		// for campaign and tutorials
-		return _("Commander");
-	}
-	else if (NetPlay.players[player].ai >= 0 && !NetPlay.players[player].allocated)
+	if (aiPlayer && GetGameMode() == GS_NORMAL && !challengeActive)
 	{
 		ASSERT_OR_RETURN("", player < MAX_PLAYERS, "invalid player: %d", player);
 		static char names[MAX_PLAYERS][StringSize];  // Must be static, since the getPlayerName() return value is used in tool tips... Long live the widget system.
@@ -582,18 +591,25 @@ const char *getPlayerName(int player)
 		return names[player];
 	}
 
+	if (static_cast<size_t>(player) >= NetPlay.players.size() || strlen(NetPlay.players[player].name) == 0)
+	{
+		// for campaign and tutorials
+		return _("Commander");
+	}
+
 	return NetPlay.players[player].name;
 }
 
 bool setPlayerName(int player, const char *sName)
 {
-	ASSERT_OR_RETURN(false, player < MAX_PLAYERS && player >= 0, "Player index (%u) out of range", player);
-	sstrcpy(playerName[player], sName);
+	ASSERT_OR_RETURN(false, player < MAX_CONNECTED_PLAYERS && player >= 0, "Player index (%u) out of range", player);
+	sstrcpy(playerName[player], sName); // Intended for long time storage of player name for Intel menu viewing.
+	sstrcpy(NetPlay.players[player].name, sName);
 	return true;
 }
 
 // ////////////////////////////////////////////////////////////////////////////
-// to determine human/computer players and responsibilities of each..
+// to determine human/computer players and responsibilities of each.
 bool isHumanPlayer(int player)
 {
 	if (player >= MAX_CONNECTED_PLAYERS || player < 0)
@@ -603,6 +619,24 @@ bool isHumanPlayer(int player)
 	return NetPlay.players[player].allocated;
 }
 
+// Clear player name data after game quit.
+void clearPlayerName(unsigned int player)
+{
+	if (player == CLEAR_ALL_NAMES)
+	{
+		for (unsigned int i = 0; i < MAX_CONNECTED_PLAYERS; ++i)
+		{
+			playerName[i][0] = '\0';
+			NetPlay.players[i].name[0] = '\0';
+		}
+	}
+	else
+	{
+		playerName[player][0] = '\0';
+		NetPlay.players[player].name[0] = '\0';
+	}
+}
+
 // returns player responsible for 'player'
 int whosResponsible(int player)
 {
@@ -1120,6 +1154,7 @@ bool shouldProcessMessage(NETQUEUE& queue, uint8_t type)
 				// kick sender for sending unauthorized message
 				char buf[255];
 				auto senderPlayerIdx = queue.index;
+				debug(LOG_INFO, "Auto kicking player %s, invalid command received: %s", NetPlay.players[senderPlayerIdx].name, messageTypeToString(type));
 				ssprintf(buf, _("Auto kicking player %s, invalid command received: %u"), NetPlay.players[senderPlayerIdx].name, type);
 				sendInGameSystemMessage(buf);
 				kickPlayer(queue.index, _("Unauthorized network command"), ERROR_INVALID);
@@ -1556,6 +1591,12 @@ bool recvResearchStatus(NETQUEUE queue)
 		// Set that facility to research
 		if (psBuilding && psBuilding->pFunctionality)
 		{
+			if (!psBuilding->pStructureType || psBuilding->pStructureType->type != REF_RESEARCH)
+			{
+				debug(LOG_INFO, "Structure is not a research facility: \"%s\".", (psBuilding->pStructureType) ? psBuilding->pStructureType->id.toUtf8().c_str() : "");
+				return false;
+			}
+
 			psResFacilty = (RESEARCH_FACILITY *) psBuilding->pFunctionality;
 
 			popStatusPending(*psResFacilty);  // Research is no longer pending, as it's actually starting now.
@@ -1612,6 +1653,12 @@ bool recvResearchStatus(NETQUEUE queue)
 		// Stop the facility doing any research
 		if (psBuilding)
 		{
+			if (!psBuilding->pStructureType || psBuilding->pStructureType->type != REF_RESEARCH)
+			{
+				debug(LOG_INFO, "Structure is not a research facility: \"%s\".", (psBuilding->pStructureType) ? psBuilding->pStructureType->id.toUtf8().c_str() : "");
+				return false;
+			}
+
 			cancelResearch(psBuilding, ModeImmediate);
 			popStatusPending(*(RESEARCH_FACILITY *)psBuilding->pFunctionality);  // Research cancellation is no longer pending, as it's actually cancelling now.
 		}
@@ -1626,6 +1673,27 @@ bool recvResearchStatus(NETQUEUE queue)
 	return true;
 }
 
+void setPlayerMuted(uint32_t playerIdx, bool muted)
+{
+	ASSERT_OR_RETURN(, playerIdx < MAX_CONNECTED_PLAYERS, "Invalid playerIdx: %" PRIu32, playerIdx);
+	if (muted == ingame.muteChat[playerIdx])
+	{
+		// no change
+		return;
+	}
+	ingame.muteChat[playerIdx] = muted;
+	if (isHumanPlayer(playerIdx))
+	{
+		storePlayerMuteOption(NetPlay.players[playerIdx].name, getMultiStats(playerIdx).identity, muted);
+	}
+}
+
+bool isPlayerMuted(uint32_t sender)
+{
+	ASSERT_OR_RETURN(false, sender < MAX_CONNECTED_PLAYERS, "Invalid sender: %" PRIu32, sender);
+	return ingame.muteChat[sender];
+}
+
 NetworkTextMessage::NetworkTextMessage(int32_t messageSender, char const *messageText)
 {
 	sender = messageSender;
@@ -1747,6 +1815,11 @@ bool receiveInGameTextMessage(NETQUEUE queue)
 		return false;
 	}
 
+	if (message.sender >= 0 && isPlayerMuted(message.sender))
+	{
+		return false;
+	}
+
 	printInGameTextMessage(message);
 
 	// make some noise!
@@ -2387,8 +2460,11 @@ bool makePlayerSpectator(uint32_t playerIndex, bool removeAllStructs, bool quiet
 		// hide the power bar
 		forceHidePowerBar(true);
 
-		// enable "god mode" for map + object visibility (+ minimap)
-		enableGodMode();
+		if (!headlessGameMode())
+		{
+			// enable "god mode" for map + object visibility (+ minimap)
+			enableGodMode();
+		}
 
 		// add spectator mode message
 		bool lowUISpectatorMode = streamer_spectator_mode() || NETisReplay();
