@@ -1,7 +1,7 @@
 /*
 	This file is part of Warzone 2100.
 	Copyright (C) 1999-2004  Eidos Interactive
-	Copyright (C) 2005-2019  Warzone 2100 Project
+	Copyright (C) 2005-2020  Warzone 2100 Project
 
 	Warzone 2100 is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 #include "lib/framework/wzconfig.h"
 #include "lib/framework/math_ext.h"
 #include "lib/framework/strres.h"
-#include "lib/framework/rational.h"
 #include "lib/gamelib/gtime.h"
 #include "console.h"
 #include "scores.h"
@@ -55,6 +54,12 @@
 #include "lib/sound/audio_id.h"
 #include "intimage.h"
 
+#include "activity.h"
+#include "multistat.h"
+#include "clparse.h"
+
+#include <algorithm>
+
 #define	BAR_CRAWL_TIME	(GAME_TICKS_PER_SEC*3)
 
 #define MT_Y_POS	(MISSIONRES_TITLE_Y  + D_H + 80)
@@ -173,7 +178,7 @@ STAT_BAR	infoBars[] =
 };
 
 // --------------------------------------------------------------------
-static void fillUpStats();
+static void fillUpStats(const END_GAME_STATS_DATA& stats);
 // --------------------------------------------------------------------
 
 /* The present mission data */
@@ -271,6 +276,26 @@ void getAsciiTime(char *psText, unsigned time)
 	}
 }
 
+END_GAME_STATS_DATA	collectEndGameStatsData()
+{
+	END_GAME_STATS_DATA fullStats;
+	fullStats.missionData = missionData;
+
+	for (size_t i = 0; i < DROID_LEVELS; i++)
+	{
+		fullStats.numDroidsPerLevel.push_back(getNumDroidsForLevel(selectedPlayer, i));
+	}
+
+	fullStats.numUnits = 0;
+	if (selectedPlayer < MAX_PLAYERS)
+	{
+		for (DROID *psDroid = apsDroidLists[selectedPlayer]; psDroid; psDroid = psDroid->psNext, fullStats.numUnits++) {}
+		for (DROID *psDroid = mission.apsDroidLists[selectedPlayer]; psDroid; psDroid = psDroid->psNext, fullStats.numUnits++) {}
+	}
+
+	return fullStats;
+}
+
 void scoreDataToScreen(WIDGET *psWidget, ScoreDataToScreenCache& cache)
 {
 	int index, x, y, width, height;
@@ -283,7 +308,7 @@ void scoreDataToScreen(WIDGET *psWidget, ScoreDataToScreenCache& cache)
 		audio_PlayTrack(ID_SOUND_BUTTON_CLICK_5);
 	}
 
-	fillUpStats();
+	fillUpStats(collectEndGameStatsData());
 
 	pie_UniTransBoxFill(16 + D_W, MT_Y_POS - 16, pie_GetVideoBufferWidth() - D_W - 16, MT_Y_POS + 256 + 16, WZCOL_SCORE_BOX);
 	iV_Box(16 + D_W, MT_Y_POS - 16, pie_GetVideoBufferWidth() - D_W - 16, MT_Y_POS + 256 + 16, WZCOL_SCORE_BOX_BORDER);
@@ -331,9 +356,9 @@ void scoreDataToScreen(WIDGET *psWidget, ScoreDataToScreenCache& cache)
 				                  (float)(realTime - dispST) / (float)BAR_CRAWL_TIME
 				                  : 1.f;
 
-				const float length = (float)infoBars[index].percent / 100.f * (float)infoBars[index].width * mul;
+				const int length = static_cast<int>((float)infoBars[index].percent / 100.f * (float)infoBars[index].width * mul);
 
-				if ((int)length > 4)
+				if (length > 4)
 				{
 
 					/* Black shadow */
@@ -344,7 +369,7 @@ void scoreDataToScreen(WIDGET *psWidget, ScoreDataToScreenCache& cache)
 				}
 			}
 			/* Now render the text by the bar */
-			sprintf(text, getDescription((MR_STRING)infoBars[index].stringID), infoBars[index].number);
+			snprintf(text, sizeof(text), getDescription((MR_STRING)infoBars[index].stringID), infoBars[index].number);
 			if (index >= cache.wzInfoBarText.size())
 			{
 				cache.wzInfoBarText.resize(index + 1);
@@ -369,49 +394,43 @@ void scoreDataToScreen(WIDGET *psWidget, ScoreDataToScreenCache& cache)
 	/* We now need to display the mission time, game time, average unit experience level an number of artefacts found */
 
 	/* Firstly, top of the screen, number of artefacts found */
-	sprintf(text, _("ARTIFACTS RECOVERED: %d"), missionData.artefactsFound);
+	snprintf(text, sizeof(text), _("ARTIFACTS RECOVERED: %d"), missionData.artefactsFound);
 	cache.wzInfoText_ArtifactsFound.setText(text, font_regular);
 	cache.wzInfoText_ArtifactsFound.render((pie_GetVideoBufferWidth() - cache.wzInfoText_ArtifactsFound.width()) / 2, 300 + D_H, WZCOL_FORM_TEXT);
 
 	/* Get the mission result time in a string - and write it out */
 	getAsciiTime((char *)&text2, gameTime - missionData.missionStarted);
-	sprintf(text, _("Mission Time - %s"), text2);
+	snprintf(text, sizeof(text), _("Mission Time - %s"), text2);
 	cache.wzInfoText_MissionTime.setText(text, font_regular);
 	cache.wzInfoText_MissionTime.render((pie_GetVideoBufferWidth() - cache.wzInfoText_MissionTime.width()) / 2, 320 + D_H, WZCOL_FORM_TEXT);
 
 	/* Write out total game time so far */
 	getAsciiTime((char *)&text2, gameTime);
-	sprintf(text, _("Total Game Time - %s"), text2);
+	snprintf(text, sizeof(text), _("Total Game Time - %s"), text2);
 	cache.wzInfoText_TotalGameTime.setText(text, font_regular);
 	cache.wzInfoText_TotalGameTime.render((pie_GetVideoBufferWidth() - cache.wzInfoText_TotalGameTime.width()) / 2, 340 + D_H, WZCOL_FORM_TEXT);
 	if (Cheated)
 	{
 		// A quick way to flash the text
 		PIELIGHT cheatedTextColor = ((realTime / 250) % 2) ? WZCOL_RED : WZCOL_YELLOW;
-		sprintf(text, "%s", _("You cheated!"));
+		snprintf(text, sizeof(text), "%s", _("You cheated!"));
 		cache.wzInfoText_Cheated.setText(text, font_regular);
 		cache.wzInfoText_Cheated.render((pie_GetVideoBufferWidth() - cache.wzInfoText_Cheated.width()) / 2, 360 + D_H, cheatedTextColor);
 	}
 }
 
 // -----------------------------------------------------------------------------------
-void	fillUpStats()
+void	fillUpStats(const END_GAME_STATS_DATA& stats)
 {
 	UDWORD	i;
-	UDWORD	maxi, num;
+	UDWORD	maxi;
 	float	scaleFactor;
 	UDWORD	length;
-	UDWORD	numUnits;
-	DROID	*psDroid;
 
 	/* Do rankings first cos they're easier */
 	for (i = 0, maxi = 0; i < DROID_LEVELS; i++)
 	{
-		num = getNumDroidsForLevel(i);
-		if (num > maxi)
-		{
-			maxi = num;
-		}
+		maxi = std::max(maxi, stats.numDroidsPerLevel[i]);
 	}
 
 	/* Make sure we got something */
@@ -427,14 +446,14 @@ void	fillUpStats()
 	/* Scale for percent */
 	for (i = 0; i < DROID_LEVELS; i++)
 	{
-		length = scaleFactor * getNumDroidsForLevel(i);
+		length = static_cast<UDWORD>(scaleFactor * stats.numDroidsPerLevel[i]);
 		infoBars[STAT_ROOKIE + i].percent = PERCENT(length, RANK_BAR_WIDTH);
-		infoBars[STAT_ROOKIE + i].number = getNumDroidsForLevel(i);
+		infoBars[STAT_ROOKIE + i].number = stats.numDroidsPerLevel[i];
 	}
 
 	/* Now do the other stuff... */
 	/* Units killed and lost... */
-	maxi = MAX(missionData.unitsLost, missionData.unitsKilled);
+	maxi = MAX(stats.missionData.unitsLost, stats.missionData.unitsKilled);
 	if (maxi == 0)
 	{
 		scaleFactor = 0.f;
@@ -444,13 +463,13 @@ void	fillUpStats()
 		scaleFactor = (float)STAT_BAR_WIDTH / maxi;
 	}
 
-	length = scaleFactor * missionData.unitsLost;
+	length = static_cast<UDWORD>(scaleFactor * stats.missionData.unitsLost);
 	infoBars[STAT_UNIT_LOST].percent = PERCENT(length, STAT_BAR_WIDTH);
-	length = scaleFactor * missionData.unitsKilled;
+	length = static_cast<UDWORD>(scaleFactor * stats.missionData.unitsKilled);
 	infoBars[STAT_UNIT_KILLED].percent = PERCENT(length, STAT_BAR_WIDTH);
 
 	/* Now do the structure losses */
-	maxi = MAX(missionData.strLost, missionData.strKilled);
+	maxi = MAX(stats.missionData.strLost, stats.missionData.strKilled);
 	if (maxi == 0)
 	{
 		scaleFactor = 0.f;
@@ -460,18 +479,15 @@ void	fillUpStats()
 		scaleFactor = (float)STAT_BAR_WIDTH / maxi;
 	}
 
-	length = scaleFactor * missionData.strLost;
+	length = static_cast<UDWORD>(scaleFactor * stats.missionData.strLost);
 	infoBars[STAT_STR_LOST].percent = PERCENT(length, STAT_BAR_WIDTH);
-	length = scaleFactor * missionData.strKilled;
+	length = static_cast<UDWORD>(scaleFactor * stats.missionData.strKilled);
 	infoBars[STAT_STR_BLOWN_UP].percent = PERCENT(length, STAT_BAR_WIDTH);
 
 	/* Finally the force information - need amount of droids as well*/
-	for (psDroid = apsDroidLists[selectedPlayer], numUnits = 0; psDroid; psDroid = psDroid->psNext, numUnits++) {}
 
-	for (psDroid = mission.apsDroidLists[selectedPlayer]; psDroid; psDroid = psDroid->psNext, numUnits++) {}
-
-	maxi = MAX(missionData.unitsBuilt, missionData.strBuilt);
-	maxi = MAX(maxi, numUnits);
+	maxi = MAX(stats.missionData.unitsBuilt, stats.missionData.strBuilt);
+	maxi = MAX(maxi, stats.numUnits);
 
 	if (maxi == 0)
 	{
@@ -482,21 +498,21 @@ void	fillUpStats()
 		scaleFactor = (float)STAT_BAR_WIDTH / maxi;
 	}
 
-	length = scaleFactor * missionData.unitsBuilt;
+	length = static_cast<UDWORD>(scaleFactor * stats.missionData.unitsBuilt);
 	infoBars[STAT_UNITS_BUILT].percent = PERCENT(length, STAT_BAR_WIDTH);
-	length = scaleFactor * numUnits;
+	length = static_cast<UDWORD>(scaleFactor * stats.numUnits);
 	infoBars[STAT_UNITS_NOW].percent = PERCENT(length, STAT_BAR_WIDTH);
-	length = scaleFactor * missionData.strBuilt;
+	length = static_cast<UDWORD>(scaleFactor * stats.missionData.strBuilt);
 	infoBars[STAT_STR_BUILT].percent = PERCENT(length, STAT_BAR_WIDTH);
 
 	/* Finally the numbers themselves */
-	infoBars[STAT_UNIT_LOST].number = missionData.unitsLost;
-	infoBars[STAT_UNIT_KILLED].number = missionData.unitsKilled;
-	infoBars[STAT_STR_LOST].number = missionData.strLost;
-	infoBars[STAT_STR_BLOWN_UP].number = missionData.strKilled;
-	infoBars[STAT_UNITS_BUILT].number =	missionData.unitsBuilt;
-	infoBars[STAT_UNITS_NOW].number = numUnits;
-	infoBars[STAT_STR_BUILT].number = missionData.strBuilt;
+	infoBars[STAT_UNIT_LOST].number = stats.missionData.unitsLost;
+	infoBars[STAT_UNIT_KILLED].number = stats.missionData.unitsKilled;
+	infoBars[STAT_STR_LOST].number = stats.missionData.strLost;
+	infoBars[STAT_STR_BLOWN_UP].number = stats.missionData.strKilled;
+	infoBars[STAT_UNITS_BUILT].number =	stats.missionData.unitsBuilt;
+	infoBars[STAT_UNITS_NOW].number = stats.numUnits;
+	infoBars[STAT_STR_BUILT].number = stats.missionData.strBuilt;
 }
 
 // -----------------------------------------------------------------------------------
@@ -544,3 +560,65 @@ bool readScoreData(const char *fileName)
 	/* Hopefully everything's just fine by now */
 	return true;
 }
+
+void stdOutGameSummary(UDWORD realTimeThrottleSeconds, bool flush_output /* = true */)
+{
+	static UDWORD lastOutputRealTime = 0;
+	if (realTimeThrottleSeconds > 0 && (realTime - lastOutputRealTime < (realTimeThrottleSeconds * GAME_TICKS_PER_SEC)))
+	{
+		return;
+	}
+	fprintf(stdout, "Game State [gameTime: %" PRIu32 "]\n", gameTime);
+	fprintf(stdout, "--------------------------------------------------------------------------------------\n");
+	if (ActivityManager::instance().getCurrentGameMode() != ActivitySink::GameMode::CAMPAIGN)
+	{
+		fprintf(stdout, " # | Player Name | Extrct Pwr | Units Killed | Structs (F/R) | Units Alive |  Power  |\n");
+		fprintf(stdout, "-- | ----------- | ---------- | ------------ | ------------- | ----------- | ------- |\n");
+		for (unsigned n = 0; n < std::min<unsigned>(MAX_PLAYERS, (unsigned)game.maxPlayers); ++n)
+		{
+			if (NetPlay.players[n].ai < 0)
+			{
+				// skip closed slots / open / empty slots
+				continue;
+			}
+			uint32_t unitsKilled = getMultiPlayUnitsKilled(n);
+			uint32_t numUnits = 0;
+			for (DROID *psDroid = apsDroidLists[n]; psDroid; psDroid = psDroid->psNext, numUnits++) {}
+			uint32_t numStructs = 0;
+			uint32_t numFactories = 0;
+			uint32_t numResearch = 0;
+			uint32_t numFactoriesThatCanProduceConstructionUnits = 0;
+			for (STRUCTURE *psStruct = apsStructLists[n]; psStruct; psStruct = psStruct->psNext, numStructs++)
+			{
+				if (psStruct->status != SS_BUILT || psStruct->died != 0)
+				{
+					continue; // ignore structures that aren't completely built, or are "dead"
+				}
+				if (StructIsFactory(psStruct))
+				{
+					numFactories++;
+					if (psStruct->pStructureType->type == REF_FACTORY ||
+						psStruct->pStructureType->type == REF_CYBORG_FACTORY)
+					{
+						numFactoriesThatCanProduceConstructionUnits++;
+					}
+				}
+				else if (psStruct->pStructureType->type == REF_RESEARCH)
+				{
+					numResearch++;
+				}
+			}
+			std::string structInfoString = std::to_string(numStructs) + " (" + std::to_string(numFactories) + "/" + std::to_string(numResearch) + ")";
+			// NOTE: This duplicates the logic in rules.js - checkEndConditions()
+			const bool playerCantDoAnything = (numFactoriesThatCanProduceConstructionUnits == 0) && (numUnits == 0);
+			const char * deadStatus = playerCantDoAnything ? "x" : "";
+			fprintf(stdout, "%2u | %11.11s | %10" PRIi64 " | %12" PRIi32 " | %13.13s | %11" PRIi32 " | %7" PRIi32 " | %s\n", n, NetPlay.players[n].name, getExtractedPower(n), unitsKilled, structInfoString.c_str(), numUnits, getPower(n), deadStatus);
+		}
+	}
+	fprintf(stdout, "--------------------------------------------------------------------------------------\n");
+	if (flush_output)
+	{
+		fflush(stdout);
+	}
+	lastOutputRealTime = realTime;
+}
