@@ -144,7 +144,7 @@ struct STRUCTURE_STATS : public BASE_STATS
 		unsigned resistance;	// resist enemy takeover; 0 = immune
 		unsigned limit;		// current max limit for this type, LOTS_OF = no limit
 	} upgrade[MAX_PLAYERS], base;
-	bool isFavorite;		///< on Favorites list
+	bool isFavorite = false;		///< on Favorites list
 
 	inline Vector2i size(uint16_t direction) const
 	{
@@ -227,13 +227,29 @@ struct POWER_GEN
 
 class DROID_GROUP;
 
+enum class RepairEvents
+{
+	NoEvents,
+	RepairTargetFound,
+	UnitReachedMaxHP,
+	UnitDied,
+	UnitMovedAway
+};
+
+enum class RepairState 
+{
+	Invalid = -1,
+	Idle,
+	Repairing
+};
+
 struct REPAIR_FACILITY
 {
 	BASE_OBJECT *psObj;                /* Object being repaired */
 	FLAG_POSITION *psDeliveryPoint;    /* Place for the repaired droids to assemble at */
 	// The group the droids to be repaired by this facility belong to
 	DROID_GROUP *psGroup;
-	int droidQueue;                    ///< Last count of droid queue for this facility
+	RepairState state;
 };
 
 struct REARM_PAD
@@ -273,7 +289,7 @@ struct STRUCTURE : public BASE_OBJECT
 	FUNCTIONALITY       *pFunctionality;            /* pointer to structure that contains fields necessary for functionality */
 	int                 buildRate;                  ///< Rate that this structure is being built, calculated each tick. Only meaningful if status == SS_BEING_BUILT. If construction hasn't started and build rate is 0, remove the structure.
 	int                 lastBuildRate;              ///< Needed if wanting the buildRate between buildRate being reset to 0 each tick and the trucks calculating it.
-	BASE_OBJECT *psTarget[MAX_WEAPONS];
+	BASE_OBJECT *psTarget[MAX_WEAPONS] = {nullptr};
 #ifdef DEBUG
 	// these are to help tracking down dangling pointers
 	char targetFunc[MAX_WEAPONS][MAX_EVENT_NAME_LEN];
