@@ -50,7 +50,7 @@
 //;;
 
 #include "lib/framework/frame.h"
-#include <optional-lite/optional.hpp>
+#include <nonstd/optional.hpp>
 #include "basedef.h"
 #include "structuredef.h"
 #include "featuredef.h"
@@ -198,7 +198,6 @@ namespace wzapi
 	public:
 		// MARK: Transporter events
 
-		//__
 		//__ ## eventTransporterLaunch(transport)
 		//__
 		//__ An event that is run when the mission transporter has been ordered to fly off.
@@ -248,61 +247,61 @@ namespace wzapi
 
 		//__ ## eventDesignBody()
 		//__
-		//__An event that is run when current user picks a body in the design menu.
+		//__ An event that is run when current user picks a body in the design menu.
 		//__
 		virtual bool handle_eventDesignBody() SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventDesignPropulsion()
 		//__
-		//__An event that is run when current user picks a propulsion in the design menu.
+		//__ An event that is run when current user picks a propulsion in the design menu.
 		//__
 		virtual bool handle_eventDesignPropulsion() SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventDesignWeapon()
 		//__
-		//__An event that is run when current user picks a weapon in the design menu.
+		//__ An event that is run when current user picks a weapon in the design menu.
 		//__
 		virtual bool handle_eventDesignWeapon() SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventDesignCommand()
 		//__
-		//__An event that is run when current user picks a command turret in the design menu.
+		//__ An event that is run when current user picks a command turret in the design menu.
 		//__
 		virtual bool handle_eventDesignCommand() SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventDesignSystem()
 		//__
-		//__An event that is run when current user picks a system other than command turret in the design menu.
+		//__ An event that is run when current user picks a system other than command turret in the design menu.
 		//__
 		virtual bool handle_eventDesignSystem() SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventDesignQuit()
 		//__
-		//__An event that is run when current user leaves the design menu.
+		//__ An event that is run when current user leaves the design menu.
 		//__
 		virtual bool handle_eventDesignQuit() SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventMenuBuildSelected()
 		//__
-		//__An event that is run when current user picks something new in the build menu.
+		//__ An event that is run when current user picks something new in the build menu.
 		//__
 		virtual bool handle_eventMenuBuildSelected(/*BASE_OBJECT *psObj*/) SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventMenuResearchSelected()
 		//__
-		//__An event that is run when current user picks something new in the research menu.
+		//__ An event that is run when current user picks something new in the research menu.
 		//__
 		virtual bool handle_eventMenuResearchSelected(/*BASE_OBJECT *psObj*/) SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventMenuBuild()
 		//__
-		//__An event that is run when current user opens the build menu.
+		//__ An event that is run when current user opens the build menu.
 		//__
 		virtual bool handle_eventMenuBuild() SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventMenuResearch()
 		//__
-		//__An event that is run when current user opens the research menu.
+		//__ An event that is run when current user opens the research menu.
 		//__
 		virtual bool handle_eventMenuResearch() SCRIPTING_EVENT_NON_REQUIRED
 
@@ -310,7 +309,8 @@ namespace wzapi
 		virtual bool handle_eventMenuDesign() SCRIPTING_EVENT_NON_REQUIRED
 
 		//__ ## eventMenuManufacture()
-		//__An event that is run when current user opens the manufacture menu.
+		//__
+		//__ An event that is run when current user opens the manufacture menu.
 		//__
 		virtual bool handle_eventMenuManufacture() SCRIPTING_EVENT_NON_REQUIRED
 
@@ -961,6 +961,7 @@ namespace wzapi
 	bool setAssemblyPoint(WZAPI_PARAMS(STRUCTURE *psStruct, int x, int y));
 	bool setSunPosition(WZAPI_PARAMS(float x, float y, float z));
 	bool setSunIntensity(WZAPI_PARAMS(float ambient_r, float ambient_g, float ambient_b, float diffuse_r, float diffuse_g, float diffuse_b, float specular_r, float specular_g, float specular_b));
+	bool setFogColour(WZAPI_PARAMS(int r, int g, int b));
 	bool setWeather(WZAPI_PARAMS(int weatherType));
 	bool setSky(WZAPI_PARAMS(std::string textureFilename, float windSpeed, float scale));
 	bool cameraSlide(WZAPI_PARAMS(float x, float y));
