@@ -74,10 +74,12 @@
 #include "template.h"
 #include "multiint.h"
 #include "challenge.h"
+#include "multistat.h"
 
 #include "wzapi.h"
 #include "qtscript.h"
 
+#include <vector>
 #include <numeric>
 #include <algorithm>
 #include <limits>
@@ -111,9 +113,8 @@ struct RowDataModel
 {
 public:
 	RowDataModel(size_t numberOfColumns)
-	{
-		m_currentMaxColumnWidths.resize(numberOfColumns, 0);
-	}
+	: m_currentMaxColumnWidths(numberOfColumns, 0)
+	{ }
 
 	std::shared_ptr<TableRow> newRow(const std::vector<WzString>& columnTexts, int rowHeight = 0, bool skipCalculatingColumnWidth = false)
 	{
@@ -252,7 +253,7 @@ static nlohmann::ordered_json fillMainModel()
 	                               "LDS_EXPAND_LIMBO", "LDS_MKEEP_LIMBO", "LDS_NONE",
 	                               "LDS_MULTI_TYPE_START", "CAMPAIGN", "", "SKIRMISH", "", "", "",
 	                               "MULTI_SKIRMISH2", "MULTI_SKIRMISH3", "MULTI_SKIRMISH4" };
-	const std::vector<std::string> difficulty_type = { "EASY", "NORMAL", "HARD", "INSANE" };
+	const std::vector<std::string> difficulty_type = { "SUPEREASY", "EASY", "NORMAL", "HARD", "INSANE" };
 	nlohmann::ordered_json result = nlohmann::ordered_json::object();
 
 	int8_t gameType = static_cast<int8_t>(game.type);
@@ -294,8 +295,8 @@ static nlohmann::ordered_json fillMainModel()
 static nlohmann::ordered_json fillPlayerModel(int i)
 {
 	nlohmann::ordered_json result = nlohmann::ordered_json::object();
-	result["ingame.skScores score"] = ingame.skScores[i][0];
-	result["ingame.skScores kills"] = ingame.skScores[i][1];
+	result["playerStats score"] = getMultiPlayRecentScore(i);
+	result["playerStats kills"] = getMultiPlayUnitsKilled(i);
 	result["NetPlay.players.name"] = NetPlay.players[i].name;
 	result["NetPlay.players.position"] = NetPlay.players[i].position;
 	result["NetPlay.players.colour"] = NetPlay.players[i].colour;
@@ -508,7 +509,7 @@ static void TabButtonDisplayFunc(WIDGET *psWidget, UDWORD xOffset, UDWORD yOffse
 
 	if (haveText)
 	{
-		cache.text.setText(psButton->pText.toUtf8(), psButton->FontID);
+		cache.text.setText(psButton->pText, psButton->FontID);
 		int fw = cache.text.width();
 		int fx = x0 + (psButton->width() - fw) / 2;
 		int fy = y0 + (psButton->height() - cache.text.lineSize()) / 2 - cache.text.aboveBase();
@@ -560,6 +561,7 @@ public:
 		powerEditField->callCalcLayout();
 		aiAttachButton->callCalcLayout();
 		aiPlayerDropdown->callCalcLayout();
+		aiDifficultyDropdown->callCalcLayout();
 		aiDropdown->callCalcLayout();
 		table->callCalcLayout();
 	}
@@ -651,7 +653,7 @@ public:
 				powerValue = std::stoi(powerString.toStdString());
 			}
 			catch (const std::exception&) {
-				debug(LOG_ERROR, "Invalid power value (not convertable to an integer - use numbers only): %s", powerString.toUtf8().c_str());
+				debug(LOG_ERROR, "Invalid power value (not convertible to an integer - use numbers only): %s", powerString.toUtf8().c_str());
 				return;
 			}
 			auto selectedPlayerCopy = selectedPlayer;
@@ -721,11 +723,14 @@ public:
 			ASSERT_OR_RETURN(, psParent != nullptr, "No parent");
 			auto selectedAiButton = psParent->aiDropdown->getSelectedItem();
 			ASSERT_OR_RETURN(, selectedAiButton != nullptr, "No selected AI?");
+			auto selectedAiDifficultyButton = psParent->aiDifficultyDropdown->getSelectedItem();
+			ASSERT_OR_RETURN(, selectedAiDifficultyButton != nullptr, "No selected AI difficulty?");
+			const AIDifficulty difficulty = static_cast<AIDifficulty>(selectedAiDifficultyButton->UserData);
 			auto selectedAiPlayerButton = psParent->aiPlayerDropdown->getSelectedItem();
 			ASSERT_OR_RETURN(, selectedAiPlayerButton != nullptr, "No selected AI player?");
 			const WzString script = selectedAiButton->getString();
 			const int player = static_cast<int>(selectedAiPlayerButton->UserData);
-			jsAutogameSpecific(WzString::fromUtf8("multiplay/skirmish/") + script, player);
+			jsAutogameSpecific(WzString::fromUtf8("multiplay/skirmish/") + script, player, difficulty);
 			debug(LOG_INFO, "Script attached - close and reopen debug window to see its context");
 		});
 		if (readOnly)
@@ -758,6 +763,40 @@ public:
 			pAiPlayerDropdown->setGeometry(x0, bottomOfPowerRow, width, TAB_BUTTONS_HEIGHT);
 		});
 
+		// AI Difficulty dropdown
+		// Easy through INSANE
+		std::vector<std::pair<AIDifficulty, std::string>> difficulties{
+				std::pair<AIDifficulty, std::string>{AIDifficulty::DEFAULT, "DEFAULT"},
+				std::pair<AIDifficulty, std::string>{AIDifficulty::EASY, "EASY"},
+				std::pair<AIDifficulty, std::string>{AIDifficulty::MEDIUM, "MEDIUM"},
+				std::pair<AIDifficulty, std::string>{AIDifficulty::HARD, "HARD"},
+				std::pair<AIDifficulty, std::string>{AIDifficulty::INSANE, "INSANE"}
+		};
+		panel->aiDifficultyDropdown = std::make_shared<DropdownWidget>();
+		panel->attach(panel->aiDifficultyDropdown);
+		panel->aiDifficultyDropdown->setListHeight(TAB_BUTTONS_HEIGHT * difficulties.size());
+
+		maxButtonTextWidth = 0;
+		for (const auto& difficulty : difficulties)
+		{
+			WzString buttonLabel = WzString::fromUtf8(difficulty.second);
+			auto button = makeDebugButton(buttonLabel.toUtf8().c_str());
+			button->UserData = static_cast<UDWORD>(difficulty.first);
+			maxButtonTextWidth = std::max<int>(button->width(), maxButtonTextWidth);
+			panel->aiDifficultyDropdown->addItem(button);
+		}
+		panel->aiDifficultyDropdown->setSelectedIndex(0);
+		panel->aiDifficultyDropdown->setCalcLayout([maxButtonTextWidth](WIDGET *psWidget) {
+			auto pAiDifficultyDropdown = static_cast<DropdownWidget *>(psWidget);
+			auto psParent = std::dynamic_pointer_cast<WzMainPanel>(psWidget->parent());
+			ASSERT_OR_RETURN(, psParent != nullptr, "No parent");
+			int width = maxButtonTextWidth + pAiDifficultyDropdown->getScrollbarWidth();
+			int x0 = psParent->aiPlayerDropdown->x() - ACTION_BUTTON_SPACING - width;
+			int bottomOfPowerRow =
+					psParent->powerEditField->y() + psParent->powerEditField->height() + ACTION_BUTTON_ROW_SPACING;
+			pAiDifficultyDropdown->setGeometry(x0, bottomOfPowerRow, width, TAB_BUTTONS_HEIGHT);
+		});
+
 		// AI names dropdown
 		const std::vector<WzString> AIs = getAINames();
 		panel->aiDropdown = std::make_shared<DropdownWidget>();
@@ -775,9 +814,11 @@ public:
 			auto pAiDropdown = static_cast<DropdownWidget *>(psWidget);
 			auto psParent = std::dynamic_pointer_cast<WzMainPanel>(psWidget->parent());
 			ASSERT_OR_RETURN(, psParent != nullptr, "No parent");
-			int x0 = psParent->attachAItoPlayerLabel->x() + psParent->attachAItoPlayerLabel->width() + ACTION_BUTTON_SPACING;
-			int bottomOfPowerRow = psParent->powerEditField->y() + psParent->powerEditField->height() + ACTION_BUTTON_ROW_SPACING;
-			int fillWidth = psParent->aiPlayerDropdown->x() - ACTION_BUTTON_SPACING - x0;
+			int x0 = psParent->attachAItoPlayerLabel->x() + psParent->attachAItoPlayerLabel->width() +
+					 ACTION_BUTTON_SPACING;
+			int bottomOfPowerRow =
+					psParent->powerEditField->y() + psParent->powerEditField->height() + ACTION_BUTTON_ROW_SPACING;
+			int fillWidth = psParent->aiDifficultyDropdown->x() - ACTION_BUTTON_SPACING - x0;
 			pAiDropdown->setGeometry(x0, bottomOfPowerRow, fillWidth, TAB_BUTTONS_HEIGHT);
 		});
 
@@ -848,6 +889,7 @@ public:
 	std::shared_ptr<W_BUTTON> powerUpdateButton;
 	std::shared_ptr<W_LABEL> attachAItoPlayerLabel;
 	std::shared_ptr<DropdownWidget> aiDropdown;
+	std::shared_ptr<DropdownWidget> aiDifficultyDropdown;
 	std::shared_ptr<DropdownWidget> aiPlayerDropdown;
 	std::shared_ptr<W_BUTTON> aiAttachButton;
 	std::shared_ptr<JSONTableWidget> table;
@@ -1347,7 +1389,7 @@ public:
 			currentMaxColumnWidths[1][1] = 0;
 			for (const auto& str : view_type)
 			{
-				currentMaxColumnWidths[1][1] = std::max(currentMaxColumnWidths[1][1], static_cast<size_t>(iV_GetTextWidth(str.toUtf8().c_str(), font_regular)));
+				currentMaxColumnWidths[1][1] = std::max(currentMaxColumnWidths[1][1], static_cast<size_t>(iV_GetTextWidth(str, font_regular)));
 			}
 			currentMaxColumnWidths[1][2] = static_cast<size_t>(width() - currentMaxColumnWidths[1][0] - currentMaxColumnWidths[1][1]);
 		}
